(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    466545,       9698]*)
(*NotebookOutlinePosition[    467783,       9736]*)
(*  CellTagsIndexPosition[    467739,       9732]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Stability of polynomials", "Title"],

Cell[TextData[{
  "Problems from the theory of ordinary differential equations, numerical \
mathematics and control theory lead to the investigation of stability of \
polynomials. Our purpose here is to review some criteria and show what \
possibilities are offered by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to illustrate and to use these."
}], "Abstract",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[
"by J\[AAcute]nos T\[OAcute]th, L\[AAcute]szl\[OAcute] Szili and \
Andr\[AAcute]s Zach\[AAcute]r"]], "Author",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["1 INTRODUCTION", "Section"],

Cell[TextData[StyleBox[
"We shall only consider polynomials with real coefficients, i.e. polynomials \
of the form"]], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm
      \`p(z) := 
        \(a\_0\) z\^N + \(a\_1\) z\^\(N - 1\) + \[CenterEllipsis] + 
          \(a\_\(N - 1\)\) z + 
          a\_N\ \ \ \ \((z\ \ \[Epsilon]\ \ \[DoubleStruckCapitalC])\)\)]]],
  " "
}], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["where "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`N\)]]],
  StyleBox[" is a fixed positive integer and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`a\_n\ \((n = 1, 2, \[CenterEllipsis], N)\)\)]]],
  StyleBox[" are real numbers. The polynomial "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`p\)]]],
  StyleBox[" is said to be "],
  StyleBox["stable",
    FontSlant->"Italic"],
  StyleBox[" if all the roots of "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`p\)]]],
  StyleBox[
  " lie in the open left half of the complex plane. In the complementary case \
the polynomial is said to be "],
  StyleBox["unstable",
    FontSlant->"Italic"],
  StyleBox["."]
}], "Text",
  FontWeight->"Plain"],

Cell["\<\
The problem emerged at the end of the last century in connection with the \
centrifugal regulator, theoretically treated by such scholars as Maxwell, \
Hermite and Liapunov. A practically useful approach to that special problem \
has been given by Vishnegradsky.\
\>", "Text",
  FontWeight->"Plain"],

Cell[TextData[StyleBox[
"An obvious approach to the problem is to calculate the roots of the \
polynomial and check if the stability condition holds or not. This is by far \
the least effective method\[LongDash]especially in the case of symbolical \
coefficients. Therefore the genuine problem is: How to check the stability \
condition only using the coefficients but without finding the roots to the \
polynomial?  "]], "Text",
  FontWeight->"Plain"],

Cell[TextData[StyleBox[
"It turns out that it is not a simple problem to find such procedures. Many \
people were involved in this area, the most well known ones being Routh, \
Stodola, Hurwitz, Li\[EAcute]nard, Chippart and Mikhajlov. The theory of \
stable polynomials (togehter with historical remarks) has been outlined in \
[2,3,4]."]], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[
  "Our aim in the present paper is twofold: First, we are going to present a \
short review of this area (as it seems to be much less known among both \
algebraists and analysts as it should be). Second, attached to each criteria \
we provide some "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[" code to illustrate and use the given method."]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[
  "Some of the given criteria can utilize the symbolic capabilities of  "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[
  "; in those cases we formulated the code so as to make this possible."],
  StyleBox[" ",
    FontSlant->"Italic"]
}], "Text",
  FontWeight->"Plain"],

Cell["\<\
No checking (as e.g. type check) is included into the codes in order to make \
them as transparent and simple as possible. Although we summarize our \
functions at the end into a single function with options, we think that \
further studies and experiments are needed until it can be considered as a \
'product'. \
\>", "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[
  "Finally, we remark that there has been an earlier approach to the \
stability of polynomials using "],
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  StyleBox["by A. Urintsev, see in "],
  StyleBox["MathSource",
    FontSlant->"Italic"],
  StyleBox["  under item number 0203\[Dash]746."]
}], "Text",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2 STODOLA'S CRITERION", "Section"],

Cell[TextData[{
  StyleBox[
  "It is easy to find a necessary condition for a polynomial to be stable. \
According to the "],
  StyleBox["Stodola  condition ",
    FontSlant->"Italic"],
  StyleBox["[2, p. 488] the polynomial "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`p\)]]],
  StyleBox[
  " can be stable only if all its coefficients are of the same sign."]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[StyleBox[
"The function below can be used to check this criterion:"]], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(Stodola[polyvalue_, variable_] := \n\ \ \ \ \ \ \ 
      Equal@@Sign[CoefficientList[polyvalue, variable]]\)], "Input",
  CellLabel->"In[1]:="],

Cell[TextData[{
  StyleBox["Let us remark that our aim is to check whether the "],
  StyleBox["sign",
    FontSlant->"Italic"],
  StyleBox[" of the "],
  StyleBox["coefficients",
    FontSlant->"Italic"],
  StyleBox[" of a polynomial are "],
  StyleBox["equal",
    FontSlant->"Italic"],
  StyleBox[
  " or not. The right hand side follows the syntax of the previous English \
sentence almost exactly. "]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[StyleBox["Let us consider the following polynomials:"]], "Text",
  FontWeight->"Plain"],

Cell[BoxData[{
    \(p\_1[z_] := z\^3 + z\^2 + 4  z + 30\), 
    \(p\_2[z_] := 0  z\^3 + z\^2 + 5  z + 3\), 
    \(p\_3[z_, a_] := 3  z\^3 + z\^2 + 5  z + a\)}], "Input",
  CellLabel->"In[2]:="],

Cell[TextData[{
  StyleBox["Let us check how the function "],
  StyleBox["Stodola[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["works."]
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Stodola[p\_1[z], z]\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["\<\
Our function considers the first nonzero coefficient to be the leading \
coefficient.\
\>", "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Stodola[p\_2[z], z]\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "As it can be seen from the examples above and from some examples below, \
cases given by "],
  StyleBox["approximate numerical values",
    FontSlant->"Italic"],
  StyleBox[" are evaluated to give either "],
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" or "],
  StyleBox["True",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[".  If the coefficients have "],
  StyleBox["exact numerical values",
    FontSlant->"Italic"],
  StyleBox[" (e.g. "],
  StyleBox["1/2",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[", "],
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(\@2\),
            FontFamily->"Courier",
            FontWeight->"Bold"], ","}], TraditionalForm]]]],
  StyleBox[" "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Pi]\/\[ExponentialE]\)]]],
  StyleBox[", "],
  StyleBox["Log[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  ") then previous versions (such as Version 2.2) may not yet give a "],
  StyleBox["False",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" or "],
  StyleBox["True ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["result."]
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(polylist1 = 
      p\_3[z, a] /. 
        a \[Rule] {\(-1\), 0, \@2, Log[2], Log[2.], Log[2, 1\/2]}; \n
    TableForm[polylist1]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\(-1\) + 5\ z + z\^2 + 3\ z\^3\)},
          {\(5\ z + z\^2 + 3\ z\^3\)},
          {\(\@2 + 5\ z + z\^2 + 3\ z\^3\)},
          {\(5\ z + z\^2 + 3\ z\^3 + Log[2]\)},
          {
            \(\(0.693147180559945308`\[InvisibleSpace]\) + 5\ z + z\^2 + 
              3\ z\^3\)},
          {\(\(-1\) + 5\ z + z\^2 + 3\ z\^3\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ -1, 
          Times[ 5, z], 
          Power[ z, 2], 
          Times[ 3, 
            Power[ z, 3]]], 
        Plus[ 
          Times[ 5, z], 
          Power[ z, 2], 
          Times[ 3, 
            Power[ z, 3]]], 
        Plus[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Times[ 5, z], 
          Power[ z, 2], 
          Times[ 3, 
            Power[ z, 3]]], 
        Plus[ 
          Times[ 5, z], 
          Power[ z, 2], 
          Times[ 3, 
            Power[ z, 3]], 
          Log[ 2]], 
        Plus[ .69314718055994529, 
          Times[ 5, z], 
          Power[ z, 2], 
          Times[ 3, 
            Power[ z, 3]]], 
        Plus[ -1, 
          Times[ 5, z], 
          Power[ z, 2], 
          Times[ 3, 
            Power[ z, 3]]]}]]], "Output",
  CellLabel->"Out[7]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Stodola[#, z]&, polylist1] // TableForm\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {"False"},
          {"False"},
          {"True"},
          {"True"},
          {"True"},
          {"False"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {False, False, True, True, True, False}]]], "Output",
  CellLabel->"Out[8]//TableForm="]
}, Open  ]],

Cell["\<\
If one also has parametric coefficients then a result of the type below will \
be given.\
\>", "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Stodola[p\_3[z, a], z]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(Sign[a] == 1\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["The criterion of Stodola is only "],
  StyleBox["necessary",
    FontSlant->"Italic"],
  StyleBox[
  " and not sufficient for the stability of a polynomial, as it is shown by \
the polynomial "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`p\_1\)]]],
  StyleBox[". "]
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Solve[p\_1[z] == 0, z]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \({{z \[Rule] \(-3\)}, {z \[Rule] 1 - 3\ I}, {z \[Rule] 1 + 3\ I}}\)], 
  "Output",
  CellLabel->"Out[10]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
3 PLOTTING THE GRAPH OF A POLYNOMIAL AND SOLVING A POLYNOMIAL EQUATION\
\>", "Section"],

Cell[TextData[{
  StyleBox[
  "If one has an easy to use and efficient tool for drawing functions on a \
computer like "],
  StyleBox["Mathematica, ",
    FontSlant->"Italic"],
  StyleBox[
  "one can try to represent the graph of the function. We can see below two \
examples."]
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p\_4[z_] := z\^5 + 31  z\^4 + 361  z\^3 + 1921  z\^2 + 4390  z + 2801\),
   
    \(\(Plot[p\_4[x], {x, \(-10.1\), \(-0.9\)}]; \)\)}], "Input",
  CellLabel->"In[11]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.0942951 0.495987 0.000660141 [
[.03324 .48349 -9 -9 ]
[.03324 .48349 9 0 ]
[.22183 .48349 -6 -9 ]
[.22183 .48349 6 0 ]
[.41042 .48349 -6 -9 ]
[.41042 .48349 6 0 ]
[.59901 .48349 -6 -9 ]
[.59901 .48349 6 0 ]
[.7876 .48349 -6 -9 ]
[.7876 .48349 6 0 ]
[.96369 .0999 -24 -4.5 ]
[.96369 .0999 0 4.5 ]
[.96369 .23193 -24 -4.5 ]
[.96369 .23193 0 4.5 ]
[.96369 .36396 -24 -4.5 ]
[.96369 .36396 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.03324 .49599 m
.03324 .50224 L
s
[(-10)] .03324 .48349 0 1 Mshowa
.22183 .49599 m
.22183 .50224 L
s
[(-8)] .22183 .48349 0 1 Mshowa
.41042 .49599 m
.41042 .50224 L
s
[(-6)] .41042 .48349 0 1 Mshowa
.59901 .49599 m
.59901 .50224 L
s
[(-4)] .59901 .48349 0 1 Mshowa
.7876 .49599 m
.7876 .50224 L
s
[(-2)] .7876 .48349 0 1 Mshowa
.125 Mabswid
.08039 .49599 m
.08039 .49974 L
s
.12753 .49599 m
.12753 .49974 L
s
.17468 .49599 m
.17468 .49974 L
s
.26898 .49599 m
.26898 .49974 L
s
.31612 .49599 m
.31612 .49974 L
s
.36327 .49599 m
.36327 .49974 L
s
.45757 .49599 m
.45757 .49974 L
s
.50471 .49599 m
.50471 .49974 L
s
.55186 .49599 m
.55186 .49974 L
s
.64616 .49599 m
.64616 .49974 L
s
.69331 .49599 m
.69331 .49974 L
s
.74045 .49599 m
.74045 .49974 L
s
.83475 .49599 m
.83475 .49974 L
s
.8819 .49599 m
.8819 .49974 L
s
.92904 .49599 m
.92904 .49974 L
s
.25 Mabswid
0 .49599 m
1 .49599 L
s
.97619 .0999 m
.98244 .0999 L
s
[(-600)] .96369 .0999 1 0 Mshowa
.97619 .23193 m
.98244 .23193 L
s
[(-400)] .96369 .23193 1 0 Mshowa
.97619 .36396 m
.98244 .36396 L
s
[(-200)] .96369 .36396 1 0 Mshowa
.125 Mabswid
.97619 .13291 m
.97994 .13291 L
s
.97619 .16592 m
.97994 .16592 L
s
.97619 .19892 m
.97994 .19892 L
s
.97619 .26494 m
.97994 .26494 L
s
.97619 .29795 m
.97994 .29795 L
s
.97619 .33095 m
.97994 .33095 L
s
.97619 .39697 m
.97994 .39697 L
s
.97619 .42997 m
.97994 .42997 L
s
.97619 .46298 m
.97994 .46298 L
s
.97619 .0669 m
.97994 .0669 L
s
.97619 .03389 m
.97994 .03389 L
s
.97619 .00088 m
.97994 .00088 L
s
.97619 .52899 m
.97994 .52899 L
s
.97619 .562 m
.97994 .562 L
s
.97619 .59501 m
.97994 .59501 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .4767 m
.03199 .49424 L
.04094 .50989 L
.05029 .52267 L
.059 .53168 L
.06399 .53571 L
.06871 .53884 L
.073 .54114 L
.07755 .54305 L
.0799 .54384 L
.08249 .54457 L
.08488 .5451 L
.08706 .54549 L
.08829 .54566 L
.08963 .54582 L
.09104 .54594 L
.09175 .54599 L
.09239 .54603 L
.09303 .54606 L
.09364 .54608 L
.09428 .54609 L
.09498 .5461 L
.09559 .5461 L
.09623 .54609 L
.09738 .54606 L
.09849 .54601 L
.0997 .54593 L
.1019 .54573 L
.10404 .54546 L
.10602 .54516 L
.1105 .54427 L
.11527 .54306 L
.13197 .53709 L
.16636 .52036 L
.18546 .51089 L
.20298 .50321 L
.22014 .49715 L
.22878 .49475 L
.23822 .49267 L
.24303 .49183 L
.24758 .49118 L
.25166 .49072 L
.25608 .49033 L
.25838 .49018 L
.2609 .49006 L
.26218 .49002 L
.26288 .48999 L
.26354 .48998 L
.26416 .48996 L
.26483 .48995 L
Mistroke
.26601 .48994 L
.26663 .48993 L
.26722 .48993 L
.26831 .48994 L
.26949 .48995 L
.27015 .48996 L
.27076 .48997 L
.2729 .49003 L
.27398 .49008 L
.27516 .49013 L
.27746 .49026 L
.27995 .49043 L
.28448 .49084 L
.29297 .49192 L
.30288 .49365 L
.31203 .49565 L
.34785 .50598 L
.38228 .51672 L
.39994 .52113 L
.40478 .52209 L
.40986 .52297 L
.41463 .52365 L
.41895 .52413 L
.42111 .52433 L
.42344 .5245 L
.42564 .52463 L
.42662 .52467 L
.42767 .52471 L
.42878 .52474 L
.42982 .52476 L
.43046 .52477 L
.43106 .52478 L
.43219 .52478 L
.43338 .52477 L
.43448 .52475 L
.43505 .52473 L
.43569 .52471 L
.43697 .52466 L
.43914 .52454 L
.44112 .5244 L
.4456 .52393 L
.44955 .52336 L
.45371 .52259 L
.46239 .52039 L
.47167 .5171 L
.48043 .51305 L
.4884 .50853 L
.50585 .49569 L
.52478 .47693 L
.56203 .42484 L
Mistroke
.59789 .35645 L
.63237 .27724 L
.66909 .18573 L
.70442 .10191 L
.72239 .06577 L
.73188 .04958 L
.74199 .03514 L
.74706 .02915 L
.75184 .02436 L
.75649 .02055 L
.76076 .01784 L
.76287 .0168 L
.76483 .01601 L
.76688 .01538 L
.76797 .01513 L
.76913 .01493 L
.7703 .01479 L
.77096 .01474 L
.77156 .01472 L
.77268 .01472 L
.77387 .01479 L
.77492 .01492 L
.77592 .0151 L
.77701 .01535 L
.77818 .0157 L
.78037 .01655 L
.7827 .01776 L
.78691 .02075 L
.79191 .02573 L
.79645 .03167 L
.80634 .04962 L
.81567 .0734 L
.82454 .10277 L
.83392 .14173 L
.85073 .23419 L
.86857 .36854 L
.88526 .53311 L
.89132 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[11]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O0?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001Q_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeX200001V]JJgY[FVmkJeY[NP5[FP00of]J66]J00<006]JJeX01V]J0000of]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00of]J66]J00<006]JJeX01V]J0000fVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX60000?fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NP01JeX00=Q[FP<000E[FP03001[FV]J03A[FP03001[FV]J
00I[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX00=M[FP03001[FV]J
00Q[FP8003=[FP03001[FV]J00I[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP02JeX00=E[FP03001[FV]J00a[FP03001[FV]J031[FP8000M[FP000?m[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`02JeX00==[FP03001[FV]J00m[FP03001[FV]J02m[FP03001[FV]J
00I[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX00=9[FP03001[FV]J
015[FP03001[FV]J02i[FP03001[FV]J00I[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`02JeX00=1[FP03001[FV]J01A[FP03001[FV]J02e[FP03001[FV]J00I[FP000?m_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX00<m[FP03001[FV]J01I[FP03001[FV]J
02a[FP03001[FV]J00I[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX0
0<m[FP03001[FV]J01I[FP03001[FV]J02a[FP8000M[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP02JeX00<i[FP03001[FV]J01Q[FP03001[FV]J02][FP03001[FV]J00I[FP00
0?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX00<e[FP03001[FV]J01Y[FP03
001[FV]J02Y[FP03001[FV]J00I[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP02JeX00<a[FP03001[FV]J01a[FP03001[FV]J02U[FP03001[FV]J00I[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/000M[NV]JKg][FV]jJeY_N`0200005f]jJeY_Nf]J001[FVmkJeY[
NP00Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg/00F]J003;JeX00`00JeY[FP0MJeX00`00JeY[FP0H
JeX00`00JeX00002JeX00`00JeX00002JeX00`00JeX00004JeX00`00JeY[FP06JeX0003oKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005_N`5[FP<0000CKg][FP00JeX006]JJgX006mk001[NV]J
001[FP00JeY_Nf]JJgX00`0000E[NV]JKg][FV]j005[FP00bV]J00<006]JJeX07f]J00<006]JJeX0
5f]J0P000f]J00<006]J00000V]J00<006]J000016]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00bF]J00<006]JJeX08F]J00<006]JJeX05f]J0P00
0f]J00<006]JJeX00V]J00<006]JJeX00f]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j009[FP00b6]J00<006]JJeX08V]J00<006]JJeX09f]J00<006]JJeX0
1V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00af]J00<006]JJeX0
96]J00<006]JJeX09V]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j009[FP00aV]J00<006]JJeX09F]J00<006]JJeX09V]J00<006]JJeX01V]J0000of]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`0066]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP800006JeY_Nf]JJgY[FVmk0F]J0035JeX00`00JeY[FP0WJeX00`00JeY[
FP0UJeX00`00JeY[FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J
0034JeX00`00JeY[FP0XJeX00`00JeY[FP0UJeX00`00JeY[FP06JeX0003oJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J0034JeX00`00JeY[FP0XJeX00`00JeY[FP0UJeX00`00JeY[
FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J0033JeX00`00JeY[
FP0ZJeX00`00JeY[FP0TJeX00`00JeY[FP06JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/00V]J0032JeX00`00JeY[FP0[JeX00`00JeY[FP0TJeX20007JeX0003oKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J0031JeX00`00JeY[FP0/JeX00`00JeY[FP0TJeX0
0`00JeY[FP06JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J0030JeX0
0`00JeY[FP0^JeX00`00JeY[FP0SJeX00`00JeY[FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX00V]J002oJeX00`00JeY[FP0_JeX00`00JeY[FP0SJeX00`00JeY[FP06JeX0
003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J002nJeX00`00JeY[FP0`JeX0
0`00JeY[FP0SJeX00`00JeY[FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000O
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX00V]J002mJeX00`00JeY[FP0bJeX00`00JeY[FP0RJeX20007JeX0003oJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J002mJeX00`00JeY[FP0bJeX00`00JeY[FP0RJeX00`00JeY[
FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J002lJeX00`00JeY[
FP0cJeX00`00JeY[FP0RJeX00`00JeY[FP06JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/00V]J002kJeX00`00JeY[FP0dJeX00`00JeY[FP0RJeX00`00JeY[FP06JeX0003oKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0008Kg][FV]jJeY_Nf]JJgY[FP<0000EJgY[FP00JeY[
NV]JKg/006]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]j005[FP00^V]J00<006]JJeX0=V]J00<006]J
JeX04V]J00H006]JJeX006]J0002JeX00`00JeX00004JeX00`00JeY[FP06JeX0003oJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[NP5[FP<00003JgY[FP0000<0000=Kg/006]j001_Nf]J001[
FP00JeY[NV]JKg/00`0000E_Nf]JJgY[FVmk005[FP00^V]J00<006]JJeX0=V]J00<006]JJeX046]J
00<006]J00000V]J00<006]J00000V]J00<006]J000016]J00<006]JJeX01V]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0026mkJeY[NV]JKg][FV]jJeX200005V]JJgX006mk001[NV]J
001[FP00JeY_Nf]JJgX006mkJeY[NV]JKg][FV]j0F]J002iJeX00`00JeY[FP0gJeX00`00JeY[FP0B
JeX01@00JeY[FV]J000016]J00<006]JJeX00f]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmk
JeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00^6]J00<006]JJeX0>F]J00<006]JJeX086]J00<006]J
JeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00]f]J00<006]J
JeX0>V]J00<006]JJeX086]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j
JeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk009[FP00]f]J00<006]JJeX0>V]J00<006]JJeX086]J0P001f]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00]V]J00<006]JJeX0?6]J00<006]JJeX07f]J
00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00]F]J
00<006]JJeX0?F]J00<006]JJeX07f]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j009[FP00]6]J00<006]JJeX0?V]J00<006]JJeX07f]J00<006]JJeX01V]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00/f]J00<006]JJeX0@6]J
00<006]JJeX07V]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP00
7fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j009[FP00/V]J00<006]JJeX0@F]J00<006]JJeX07V]J0P001f]J0000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00/V]J00<006]JJeX0@F]J00<006]JJeX07V]J00<006]J
JeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00/F]J00<006]J
JeX0@V]J00<006]JJeX07V]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk009[FP00/6]J00<006]JJeX0A6]J00<006]JJeX07F]J00<006]JJeX01V]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00[f]J00<006]JJeX0AF]J00<006]J
JeX07F]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_N`0066]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP800006JeY_Nf]JJgY[FVmk
0F]J002^JeX00`00JeY[FP16JeX00`00JeY[FP0MJeX00`00JeY[FP06JeX0003oKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J002]JeX00`00JeY[FP18JeX00`00JeY[FP0LJeX00`00
JeY[FP06JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J002/JeX00`00
JeY[FP19JeX00`00JeY[FP0LJeX00`00JeY[FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J
Kg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX00V]J002[JeX00`00JeY[FP1:JeX00`00JeY[FP0LJeX00`00JeY[FP06JeX0003o
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmk0007JgY[FVmkJeY[NV]JKg/00`0001I[FVmkJeX0
06]JKg][FV]j001_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_N`5[FP00ZV]J00<006]JJeX0C6]J00<0
06]JJeX02V]J00<006]JJeX00V]J00<006]J00000V]J00<006]J000016]J00<006]JJeX01V]J0000
ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NP01Kg/1JeX300004fmkJeY[NP00Kg][FV]j001_
N`00JgY[FP00JeX006]JKg][FV]j00<00005JgY[FVmkJeY[NP01JeX00:U[FP03001[FV]J04e[FP03
001[FV]J00][FP07001[FV]JJeX006]J00000V]J00<006]J000016]J00<006]JJeX01V]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00Z6]J00<006]JJeX0CV]J00<006]J
JeX02f]J00<006]JJeX00V]J00<006]JJeX00V]J00<006]JJeX00f]J00<006]JJeX01V]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00Yf]J00<006]JJeX0Cf]J00<006]J
JeX06f]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_N`007f]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[
FP00YV]J00<006]JJeX0DF]J00<006]JJeX06V]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]J001[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00YF]J00<006]JJeX0DV]J00<006]JJeX06V]J0P001f]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00Y6]J00<006]JJeX0Df]J
00<006]JJeX06V]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NP00
7fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j009[FP00Xf]J00<006]JJeX0E6]J00<006]JJeX06V]J00<006]JJeX01V]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00XV]J00<006]JJeX0EF]J00<006]JJeX06V]J
00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NP007fmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00XF]J
00<006]JJeX0EV]J00<006]JJeX06V]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk009[FP00X6]J00<006]JJeX0F6]J00<006]JJeX06F]J0P001f]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00WV]J00<006]JJeX0FV]J00<006]J
JeX06F]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_N`007f]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[
FP00WF]J00<006]JJeX0Ff]J00<006]JJeX06F]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00Vf]J00<006]JJeX0GF]J00<006]JJeX06F]J00<006]J
JeX01V]J00001f]jJeY_Nf]JJgY[FVmk00D0001ZJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX20000=F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00`00039[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0`0003Y[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_N`5[FP002F]J00L006]JJeY[FP00
JeX0000`JeX00`00JeX0000cJeX00`00JeX0000QJeX00`00JeY[FP0AJeX00`00JeY[FP0aJeX00`00
JeY[FP0FJeX00`00JeY[FP0IJeX00`00JeY[FP06JeX00003Kg][FV]j00<0000eJgY[FVmk001[NV]J
Kg/006]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP030000<f]jJeX006]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`030000<fmkJeX006]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP0300000f]jJeX000030000;FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`03
0000=fmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j00800006
JeY[NV]JKg][FV]j0F]J0009JeX01`00JeY[FV]J001[FP00035[FP03001[FV]J039[FP80021[FP03
001[FV]J015[FP03001[FP0003A[FP03001[FV]J01E[FP03001[FV]J01U[FP03001[FV]J00I[FP00
0:e[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NP00Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080001`JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FP00JeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg/1JeX000Q[FP8000A[FP03001[FV]J
031[FP03001[FV]J03=[FP8001i[FP03001[FV]J01A[FP03001[FV]J039[FP03001[FV]J01I[FP03
001[FV]J01Q[FP03001[FV]J00I[FP000?m_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgX001m_
Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP02JeX000M[FP03001[FV]J08][FP03001[FV]J06A[FP03001[FV]J01Q[FP03001[FV]J00I[FP00
0?m[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg/001m[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX000Q[FP03001[FV]J08Q[FP03
001[FV]J06I[FP03001[FV]J01Q[FP03001[FV]J00I[FP0004E_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/04@00
0<U[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgX00F]J0009JeX00`00JeY[
FP0eJeX4000AJeX5000fJeX00`00JeY[FP1XJeX00`00JeY[FP0HJeX00`00JeY[FP06JeX00?l00200
005[FP002F]J0P0036]J00<006]JJeX02V]J00<006]JJeX02f]J00<006]JJeX01f]J0P0000=[FP00
JeX036]J00<006]JJeX02V]J00@006]JJeY[FP@000I[FP03001[FV]J00Y[FP03001[FV]J00][FP03
001[FV]J00Q[FP<000e[FP03001[FV]J00Y[FP03001[FV]J00][FP03001[FV]J00Y[FP03001[FV]J
00][FP03001[FV]J00Y[FP03001[FV]J00][FP03001[FV]J00Y[FP03001[FV]J00][FP03001[FV]J
00Y[FP03001[FV]J00I[FP0003U_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/00`0002I_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0`000;Y[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgX1JeX000][
FP03001[FV]J02U[FP8002a[FP<002=[FP8006m[FP03001[FV]J01Q[FP03001[FV]J00I[FP0003E[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080000aJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0100001e[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080002DJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg/1JeX000e[FP03001[FV]J02=[FP8003M[
FP<001U[FP03001[FV]J079[FP03001[FV]J01M[FP03001[FV]J00I[FP00035_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000?6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP80000EJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J0080002GKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgX00F]J000>JeX00`00JeY[FP0MJeX30010JeX70009JeX5
001gJeX00`00JeY[FP0GJeX00`00JeY[FP06JeX0000/JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FP80001:Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FPT0002NJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_N`5[FP00
46]J00<006]JJeX05f]J0P00dF]J00<006]JJeX05f]J0P001f]J0000:6mkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J0P000?E[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]j005[FP004V]J00<006]JJeX046]J0`00eF]J00<006]JJeX05f]J00<0
06]JJeX01V]J00004f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk00<0000=Kg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P000?Y[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_N`5[FP005V]J0P00
1f]J1000fV]J00<006]JJeX05f]J00<006]JJeX01V]J000066mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FPL0003nJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_N`=[
FP00oV]J00<006]JJeX05V]J00<006]JJeX01V]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX000007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk009[FP00oV]J00<006]JJeX05V]J00<006]JJeX01V]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX0000066mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FP800006JeY[NV]JKg][FV]j0F]J003nJeX00`00JeY[FP0FJeX00`00JeY[FP06JeX0003o
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J003nJeX00`00JeY[FP0FJeX00`00
JeY[FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00000OKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J003nJeX00`00
JeY[FP0FJeX00`00JeY[FP06JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00000OJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
0V]J003oJeX00`00JeY[FP0EJeX00`00JeY[FP06JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX00V]J003oJeX00`00JeY[FP0EJeX00`00JeY[FP06JeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk000HJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J0P0000I[FVmkJeY[NV]JKg/1JeX00?m[FP03001[FV]J01E[FP03001[FV]J00I[FP00
0?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX00?m[FQQ[FP03001[FV]J00I[
FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX00?m[FQQ[FP03001[FV]J
00I[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX00001\
\>"],
  ImageRangeCache->{{{134.875, 421.875}, {406, 229.063}} -> {-15.3618, 
  460.685, 0.0370429, 5.29124}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p\_5[z_] := 4  z\^5 + 4  z\^4 + 8  z\^3 + 5  z\^2 + 3  z + 1\), 
    \(\(Plot[p\_5[x], {x, \(-2\), 2}]; \)\)}], "Input",
  CellLabel->"In[13]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.299438 0.00251967 [
[.02381 .28694 -6 -9 ]
[.02381 .28694 6 0 ]
[.2619 .28694 -6 -9 ]
[.2619 .28694 6 0 ]
[.7381 .28694 -3 -9 ]
[.7381 .28694 3 0 ]
[.97619 .28694 -3 -9 ]
[.97619 .28694 3 0 ]
[.4875 .04747 -24 -4.5 ]
[.4875 .04747 0 4.5 ]
[.4875 .17345 -18 -4.5 ]
[.4875 .17345 0 4.5 ]
[.4875 .42542 -12 -4.5 ]
[.4875 .42542 0 4.5 ]
[.4875 .5514 -18 -4.5 ]
[.4875 .5514 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .29944 m
.02381 .30569 L
s
[(-2)] .02381 .28694 0 1 Mshowa
.2619 .29944 m
.2619 .30569 L
s
[(-1)] .2619 .28694 0 1 Mshowa
.7381 .29944 m
.7381 .30569 L
s
[(1)] .7381 .28694 0 1 Mshowa
.97619 .29944 m
.97619 .30569 L
s
[(2)] .97619 .28694 0 1 Mshowa
.125 Mabswid
.07143 .29944 m
.07143 .30319 L
s
.11905 .29944 m
.11905 .30319 L
s
.16667 .29944 m
.16667 .30319 L
s
.21429 .29944 m
.21429 .30319 L
s
.30952 .29944 m
.30952 .30319 L
s
.35714 .29944 m
.35714 .30319 L
s
.40476 .29944 m
.40476 .30319 L
s
.45238 .29944 m
.45238 .30319 L
s
.54762 .29944 m
.54762 .30319 L
s
.59524 .29944 m
.59524 .30319 L
s
.64286 .29944 m
.64286 .30319 L
s
.69048 .29944 m
.69048 .30319 L
s
.78571 .29944 m
.78571 .30319 L
s
.83333 .29944 m
.83333 .30319 L
s
.88095 .29944 m
.88095 .30319 L
s
.92857 .29944 m
.92857 .30319 L
s
.25 Mabswid
0 .29944 m
1 .29944 L
s
.5 .04747 m
.50625 .04747 L
s
[(-100)] .4875 .04747 1 0 Mshowa
.5 .17345 m
.50625 .17345 L
s
[(-50)] .4875 .17345 1 0 Mshowa
.5 .42542 m
.50625 .42542 L
s
[(50)] .4875 .42542 1 0 Mshowa
.5 .5514 m
.50625 .5514 L
s
[(100)] .4875 .5514 1 0 Mshowa
.125 Mabswid
.5 .07267 m
.50375 .07267 L
s
.5 .09786 m
.50375 .09786 L
s
.5 .12306 m
.50375 .12306 L
s
.5 .14826 m
.50375 .14826 L
s
.5 .19865 m
.50375 .19865 L
s
.5 .22385 m
.50375 .22385 L
s
.5 .24904 m
.50375 .24904 L
s
.5 .27424 m
.50375 .27424 L
s
.5 .32463 m
.50375 .32463 L
s
.5 .34983 m
.50375 .34983 L
s
.5 .37503 m
.50375 .37503 L
s
.5 .40022 m
.50375 .40022 L
s
.5 .45062 m
.50375 .45062 L
s
.5 .47581 m
.50375 .47581 L
s
.5 .50101 m
.50375 .50101 L
s
.5 .52621 m
.50375 .52621 L
s
.5 .02227 m
.50375 .02227 L
s
.5 .5766 m
.50375 .5766 L
s
.5 .6018 m
.50375 .6018 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.04262 .06462 L
.06244 .1092 L
.08426 .14995 L
.10458 .18116 L
.14264 .22521 L
.16305 .24258 L
.18163 .25532 L
.20239 .26668 L
.22156 .27491 L
.24021 .28122 L
.25997 .2864 L
.27951 .2903 L
.29781 .29307 L
.31806 .29535 L
.33658 .29689 L
.35557 .29805 L
.37629 .29896 L
.39596 .29959 L
.41693 .30009 L
.45852 .30092 L
.47938 .30138 L
.49858 .30191 L
.51733 .30258 L
.53713 .30353 L
.55677 .30479 L
.57511 .30636 L
.59546 .30868 L
.61401 .31146 L
.6331 .31518 L
.65386 .32044 L
.67363 .32692 L
.69464 .33575 L
.73239 .35816 L
.75174 .37377 L
.77259 .39452 L
.79224 .41844 L
.81373 .45033 L
.85336 .52828 L
s
.85336 .52828 m
.88575 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[13]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O0?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX008m[FP03001[FV]J08i[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX008m[FP03001[FV]J08i[FP000?m_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX000M[FP03001[FV]J08E[FP03001[FV]J08i[FP00
08m[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080002>JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX000Q[FP03001[FV]J08A[FP03
001[FV]J08i[FP000?m_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX000U[FP03
001[FV]J08=[FP03001[FV]J08i[FP000?m[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[
NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`02JeX000Y[FP03001[FV]J06m[FPD0009[FP03001[FV]J009[FP03001[FV]J00A[FP03001[FV]J
08i[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FP00JeX006]JJgX006mk001[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][
FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX000Y[FP03001[FV]J
06][FP<000=[FP07001[FV]JJeX006]J00000V]J00<006]J00001F]J0`00SV]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]J001[FP00JeY_N`00JgX006mkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP002f]J00<006]JJeX0L6]J00L006]JJeY[FP00
JeX00002JeX00`00JeX00005JeX00`00JeY[FP2>JeX0001mKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000X6]JKg][FV]j
001_Nf]JJgY[FP00JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0F]J000<JeX00`00JeY[FP20JeX00`00JeY[FP2>JeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000<JeX00`00JeY[FP20JeX00`00JeY[FP2>JeX0002?
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000SV]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000=JeX00`00JeY[FP1oJeX00`00
JeY[FP2>JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000>JeX00`00
JeY[FP1nJeX00`00JeY[FP2>JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
0V]J000?JeX00`00JeY[FP1mJeX00`00JeY[FP2>JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/00V]J000@JeX00`00JeY[FP1lJeX00`00JeY[FP2>JeX0002?Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000SV]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000AJeX00`00JeY[FP1kJeX00`00JeY[FP2>JeX0003o
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000BJeX00`00JeY[FP1jJeX00`00
JeY[FP2>JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000CJeX00`00
JeY[FP1iJeX00`00JeY[FP2>JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg/0
0V]J000DJeX00`00JeY[FP1hJeX2002?JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgX00V]J000EJeX00`00JeY[FP1gJeX00`00JeY[FP2>JeX0003oJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg/00V]J000FJeX00`00JeY[FP1fJeX00`00JeY[FP2>JeX0003oKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgX00V]J000GJeX00`00JeY[FP1eJeX00`00JeY[FP2>
JeX0002?JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000SV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000IJeX00`00JeY[FP1c
JeX00`00JeY[FP2>JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgX00V]J000J
JeX00`00JeY[FP1bJeX00`00JeY[FP2>JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[
NV]JKg/00V]J000KJeX00`00JeY[FP1UJeX00`00JeY[FP02JeX00`00JeY[FP04JeX00`00JeY[FP2>
JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J001[FV]j001_N`00JgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgX00V]J000MJeX00`00JeY[FP1M
JeX30004JeX01P00JeY[FP00JeX000E[FP<008i[FP00089[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80002K
JgY[FVmk001[NP00Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`01JeX001i[FP03001[FV]J065[FP03001[FV]J009[FP03001[FP0000E[FP03001[
FV]J08i[FP00089_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP<0002JJeY[NV]J001[FV]jJeY_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0021[FP03001[FV]J
06a[FP03001[FV]J08i[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX0
025[FP03001[FV]J06][FP03001[FV]J08i[FP0008m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j0080002>JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX1JeX002=[FP03001[FV]J06U[FP03001[FV]J08i[FP000?m[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`02JeX002E[FP03001[FV]J06M[FP03001[FV]J08i[FP000?m_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX002I[FP03001[FV]J06I[FP03001[FV]J
08i[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX002Q[FP03001[FV]J
06A[FP03001[FV]J08i[FP0008m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j0080002>JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0
02Y[FP03001[FV]J069[FP03001[FV]J08i[FP000?m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`02JeX002a[FP80065[FP03001[FV]J08i[FP000?m_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP02JeX002m[FP03001[FV]J05e[FP03001[FV]J08i[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX0035[FP8005a[FP8008m[FP000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX003A[FP03001[FV]J05Q[FP03001[FV]J08i[FP00
00Q[NV]JKg][FV]jJeY_Nf]J0`0002Y[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX2000056]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/50000PF]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP050000
@6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J0`0000I[FVmkJeY[NV]JKg/1JeX000Q[FP03001[FV]J02a[FP8001A[FP03001[FV]J
03m[FP03001[FV]J045[FP03001[FV]J041[FP03001[FV]J00M[FP0000=_Nf]JJgX00`0003=[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00`0000]_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j00<0003EJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]j005[FP002F]J00<006]JJeX0<6]J0P003f]J00<006]JJeX0?f]J00<0
06]JJeX0@F]J00<006]JJeX0@F]J00<006]JJeX01V]J0000?V]jJeY_Nf]JJgY[FVmkJeX006]J001[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX30000CV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`80002>JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J001[
FVmkJeY[NV]JKg/1JeX000U[FP03001[FV]J03E[FP<000Q[FP80045[FP03001[FV]J041[FP8004=[
FP03001[FV]J00I[FP0004A_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0`000=Q[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX004M[FP80
04I[FP03001[FV]J08i[FP0004U[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP040000dV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00CF]J
2`00=f]J00<006]JJeX0SV]J0000F6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J1P000<5[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX00?l00200
005[FP0007e[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FVmkJeY[NV]JKg][FV]j02400021Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk005[FP001f]J00<006]JJeX0
@F]J00<006]JJeX0@F]J00<006]JJeX02f]J2`00:f]J00<006]JJeX0@F]J00<006]JJeX01V]J0000
Z6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FPD0001bJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J002?JeX00`00JeY[FP0KJeX6001]JeX0002c
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`05
0000If]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00Sf]J00<006]JJeX09V]J1@00Hf]J0000
SfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P0002a[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk0`0005m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00Sf]J00<006]JJeX0;V]J0P00
GV]J0000`V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000Ff]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00Sf]J00<006]JJeX0
<V]J0P00FV]J0000aVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
06mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80001GKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00Sf]J00<0
06]JJeX0=V]J0P00EV]J0000bV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J0P0005=[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00
Sf]J00<006]JJeX0>V]J0P00DV]J0000SfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX00P0003e[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FP020000CfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j005[FP00Sf]J00<006]JJeX0?V]J0P00CV]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk009[FP00Sf]J00<006]JJeX0@F]J00<006]JJeX0BV]J0000ofmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00Sf]J00<006]JJeX0@f]J00<006]JJeX0B6]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00Sf]J0P00AV]J00<006]JJeX0AV]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00Sf]J00<006]JJeX0Af]J
00<006]JJeX0A6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00Sf]J
00<006]JJeX0BF]J00<006]JJeX0@V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
7fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j009[FP00Sf]J00<006]JJeX0Bf]J00<006]JJeX0@6]J0000Sf]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0008i[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`5[FP00Sf]J00<006]JJeX0CF]J00<006]JJeX0?V]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00Sf]J00<006]JJeX0Cf]J00<006]JJeX0?6]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00Pf]J00<006]JJeX00V]J
00<006]JJeX016]J00<006]JJeX0DF]J00<006]JJeX0>V]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FP00JeY[NP00Kg/006]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j009[FP00Q6]J00H006]JJeX006]J0005JeX3001BJeX00`00JeY[FP0iJeX0
0022JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000Vf]jJeY_N`00JgX006mkJeY[NV]JKg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J0022JeX00`00JeY[FP02JeX0
0`00JeX00005JeX00`00JeY[FP1DJeX00`00JeY[FP0gJeX00022Kg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX3
0000VV]JJgY[FP00JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0F]J002?JeX00`00JeY[FP1EJeX00`00JeY[FP0fJeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J002?JeX00`00JeY[FP1FJeX00`00JeY[FP0eJeX0003o
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J002?JeX2001HJeX00`00JeY[FP0d
JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J002?JeX00`00JeY[FP1H
JeX00`00JeY[FP0cJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J002?
JeX00`00JeY[FP1IJeX00`00JeY[FP0bJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/00V]J002?JeX00`00JeY[FP1JJeX00`00JeY[FP0aJeX0002?Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000SV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j0F]J002?JeX00`00JeY[FP1KJeX00`00JeY[FP0`JeX0003oJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J002?JeX00`00JeY[FP1LJeX00`00JeY[FP0_
JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J002?JeX00`00JeY[FP1M
JeX00`00JeY[FP0^JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J002?
JeX2001OJeX00`00JeY[FP0]JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
0V]J002?JeX00`00JeY[FP1OJeX00`00JeY[FP0/JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/00V]J002?JeX00`00JeY[FP1PJeX00`00JeY[FP0[JeX0003oKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J002?JeX00`00JeY[FP1QJeX00`00JeY[FP0ZJeX0002?
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000SV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J002?JeX00`00JeY[FP1RJeX00`00
JeY[FP0YJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J002?JeX00`00
JeY[FP1SJeX00`00JeY[FP0XJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmk000OJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
0V]J001lJeX50002JeX00`00JeY[FP02JeX00`00JeY[FP04JeX00`00JeY[FP1SJeX00`00JeY[FP0X
JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeX006]J001[FV]j001_N`00JgY[FVmkJeY[NP00Kg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J001nJeX01`00JeY[FV]J
001[FP00009[FP03001[FP0000E[FP<006A[FP03001[FV]J02M[FP000?m[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FP00JeX006]JKg/006]j001_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`02JeX007i[FP07001[FV]JJeX006]J00000V]J00<006]J00001F]J
00<006]JJeX0IF]J00<006]JJeX09V]J0000OFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P000:1[FVmkJeY[NP00Kg][FV]j
JeX006]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP5[FP00Sf]J00<006]JJeX0IV]J00<006]JJeX09F]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk009[FP00Sf]J00<006]JJeX0IV]J00<006]JJeX09F]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00Sf]J0P00J6]J00<006]JJeX096]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00Sf]J00<006]JJeX0J6]J00<006]J
JeX08f]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00Sf]J00<006]J
JeX0J6]J00<006]JJeX08f]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_N`007f]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[
FP00Sf]J00<006]JJeX0JF]J00<006]JJeX08V]J0000SfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX00P0008i[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP5[FP00Sf]J00<006]JJeX0JV]J00<006]JJeX08F]J0000of]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP00JeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00Sf]J00<006]JJeX0Jf]J00<006]JJeX086]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00\
\>"],
  ImageRangeCache->{{{134.875, 421.875}, {653.563, 476.625}} -> {-4.08389, 
  541.893, 0.0146705, 1.38628}}]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "In the first case the polynomial has five real roots and it is a very \
lucky example because one can see every root and one can state easily that \
the polynomial "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`p\_4\)]]],
  StyleBox[
  " is stable. The second polynomial has one real and four complex roots. "]
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(NSolve[p\_5[z] == 0, \ z]\),
      FontColor->GrayLevel[0]]], "Input",
  CellLabel->"In[15]:=",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \({{z \[Rule] \(-0.458585258131016892`\)}, {
        z \[Rule] \(-0.140178192298154691`\) - 1.10391163385436685`\ I}, {
        z \[Rule] \(-0.140178192298154691`\) + 1.10391163385436685`\ I}, {
        z \[Rule] \(-0.13052917863633684`\) - 0.650551393972822999`\ I}, {
        z \[Rule] \(-0.13052917863633684`\) + 0.650551393972822999`\ I}}\)], 
  "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[TextData[{
  "But there are some problems, first, one may not get the exact values of \
the roots graphically, and, second, the ",
  StyleBox["Plot[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function does not show the complex roots (as for example in the second \
case)."
}], "Text",
  FormatType->TextForm,
  FontWeight->"Plain"],

Cell[TextData[{
  "Let us see what help can be obtained if we want to calculate the roots. \
The function ",
  StyleBox["Solve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can be used to symbolically find the roots of many polynomial equations \
(even with symbolic coefficients), still its area of validity is rather \
limited. One can however solve the equation ",
  Cell[BoxData[
      \(TraditionalForm\`p(x) = 0\)]],
  " numerically with the ",
  StyleBox["NSolve[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function which gives a list of numerical approximations to the roots of a \
polynomial equation."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["Here is a one-liner solving our problem based on "],
  StyleBox["NSolve[].",
    FontFamily->"Courier",
    FontWeight->"Bold"]
}], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(NegativeRealPartsQ[polyvalue_, variable_] := \n\t\ \ 
      And@@Negative[Re[variable /. NSolve[polyvalue == 0, variable]]]\n\)\)], 
  "Input",
  CellLabel->"In[16]:="],

Cell[TextData[StyleBox["Let us see some examples."]], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(p\_6[z_] := 3  z\^3 + 2  z\^2 + 5  z - 1\), 
    \(p\_7[z_] := z\^4 + 2  z\^3 + z\^2 + z + 1\), 
    \(p\_8[z_] := Evaluate[\[Sum]\+\(k = 0\)\%4 z\^k\/\(k!\)]\), 
    \(p\_9[z_] := Evaluate[\(\(\ \[Sum]\)\+\(k = 0\)\%5\) z\^k\/\(k!\)]\), 
    \(\(NegativeRealPartsQ[#[z], z]&\)\ /@
      \ {p\_1, p\_4, p\_5, p\_6, p\_7, p\_8, p\_9}\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \({False, True, True, False, False, True, False}\)], "Output",
  CellLabel->"Out[21]="]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "The above function should be applied carefully because if the degree of \
the polynomial is high the numerical method used by  "],
  StyleBox["NSolve[] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[
  "may not provide a reliable result as a consequence of rounding errors. As \
an example we ask the reader to compare the known roots of"]
}], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(p\_100[z_] := 
      Evaluate[Expand[\[Product]\+\(i = 1\)\%100\((z + N[\@i])\)]]\)], "Input",\

  CellLabel->"In[22]:="],

Cell[TextData[StyleBox["with the results obtained by"]], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(NSolve[p\_100[z] == 0, z]; \)\)], "Input",
  CellLabel->"In[23]:="],

Cell[TextData[{
  StyleBox[
  "Increasing precision may lead to reliable results. (No wonder that neither \
Maple V, nor Derive nor MATLAB performs better at this point: the effect \
highly depends on the chosen machine precision of the given mathematical \
program package.) According to our experience "],
  StyleBox["one and a half time the degree of the polynomial",
    FontSlant->"Italic"],
  StyleBox[
  " as precision suffices. For example, the roots of the (approximately \
defined!) polynomial"]
}], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(q\_100[z_] := 
      Evaluate[Expand[\[Product]\+\(i = 1\)\%100\((z + N[\@i, 150])\)]]\)], 
  "Input",
  CellLabel->"In[23]:="],

Cell["can be obtained by ", "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    StyleBox[\(NSolve[q\_100[z] == 0, z, 150]; \),
      FontColor->GrayLevel[0]]], "Input",
  CellLabel->"In[25]:=",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  StyleBox["This rescue manoeuvre however makes the calculations "],
  StyleBox["essentially",
    FontSlant->"Italic"],
  StyleBox[" slower."]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["In the case of coefficients containing parameters the use of  "],
  StyleBox["NSolve[] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["is rather limited."]
}], "Text",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["4 THE HERMITE\[Dash]MIKHAJLOV CRITERION"], "Section"],

Cell["\<\
This criterion of geometric character has been found by Hermite in 1851 and \
rediscovered and popularized among engineers by Mikhajlov in 1937.\
\>", "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "Let us start from the fact that polynomial (1) is an analytical function \
on the complex plane. As a consequence of Cauchy's theorem it is completely \
determined by its values taken on on a single line of the complex plane. Let \
this line be the imaginary axis. Then the range ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_p\)]],
  " of the map"
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm
      \`\(\[DoubleStruckCapitalR] \[ReverseElement] 
        t \[RightTeeArrow] p(i\ t) \[Element] \[DoubleStruckCapitalC]\ \ 
      \)\)],
    FontColor->GrayLevel[0]],
  StyleBox[" ",
    FontColor->GrayLevel[0]]
}], "DisplayFormula",
  FontColor->RGBColor[1, 0, 0]],

Cell[TextData[{
  "is the image of the imaginary axis. This curve is usually called as the ",
  StyleBox["amplitude-phase characteristic",
    FontSlant->"Italic"],
  " or ",
  StyleBox["Mikhajlov's hodograph",
    FontSlant->"Italic"],
  " of the polynomial ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`p\)]]],
  ". Certain geometric properties of ",
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_p\)]]],
  " are strongly conneceted with the stability of the underlying polynomial."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "The following statement is said to be the ",
  StyleBox["amplitude-phase citerion of stability",
    FontSlant->"Italic"],
  " (see [4, p. 37])."
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Theorem 1", "Subsubsection"],

Cell[TextData[{
  StyleBox["The polynomial ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " ",
  StyleBox["is stable if and only if the curve ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_p\)],
    FontSlant->"Italic"],
  StyleBox[
  " does not cross the origin and turns around the origine in positive \
direction (or: anticlockwise) at an angle of ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`n\ \[Pi]\)],
    FontSlant->"Italic"],
  StyleBox[" while its parameter ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`t\)],
    FontSlant->"Italic"],
  StyleBox[" changes from ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)],
    FontSlant->"Italic"],
  StyleBox[" to ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\(+\[Infinity]\)\)],
    FontSlant->"Italic"],
  StyleBox[".",
    FontSlant->"Italic"]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "Let us draw the amplitude-phase characteristic of the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`p\_5\)]],
  "."
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[{Re[p\_5[I\ t]], Im[p\_5[I\ t]]}, {t, \(-5\), 5}, 
      PlotRange \[Rule] {\(-1.5\), 1.5}, 
      Ticks \[Rule] {{1.5, 3}, {\(-1.5\), 1.5}}, 
      Prolog \[Rule] {Text["\<t=1.29\>", {4.5, \(-1\)}], PointSize[0.015], 
          Point[{Re[p\_5[1.29  I]], Im[p\_5[1.29  I]]}], 
          Point[{Re[p\_5[\(-1.29\) I]], Im[p\_5[\(-1.29\) I]]}]}]; \)\)], 
  "Input",
  CellLabel->"In[24]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.156486 0.235909 0.309017 0.206011 [
[.51035 .29652 -9 -9 ]
[.51035 .29652 9 0 ]
[.86421 .29652 -3 -9 ]
[.86421 .29652 3 0 ]
[.14399 0 -24 -4.5 ]
[.14399 0 0 4.5 ]
[.14399 .61803 -18 -4.5 ]
[.14399 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.51035 .30902 m
.51035 .31527 L
s
[(1.5)] .51035 .29652 0 1 Mshowa
.86421 .30902 m
.86421 .31527 L
s
[(3)] .86421 .29652 0 1 Mshowa
0 .30902 m
1 .30902 L
s
.15649 0 m
.16274 0 L
s
[(-1.5)] .14399 0 1 0 Mshowa
.15649 .61803 m
.16274 .61803 L
s
[(1.5)] .14399 .61803 1 0 Mshowa
.15649 0 m
.15649 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
gsave
1.21808 .10301 -81 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1.29) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.5 Mabswid
1 .12714 m
.82801 .25724 L
.64678 .36688 L
.48147 .44796 L
.40415 .47778 L
.3402 .49742 L
.31138 .5045 L
.28576 .50972 L
.25803 .51409 L
.23451 .51663 L
.21182 .51791 L
.1887 .51786 L
.17773 .51729 L
.16647 .51629 L
.14742 .51354 L
.13003 .50966 L
.11496 .50503 L
.10256 .50013 L
.09025 .49407 L
.06648 .47771 L
.05669 .46831 L
.04749 .45718 L
.04096 .4472 L
.03518 .43598 L
.03087 .42501 L
.02786 .41471 L
.02558 .40345 L
.02429 .39268 L
.02381 .38291 L
.02399 .37227 L
.02497 .36065 L
.02576 .35479 L
.02685 .34837 L
.02934 .33706 L
.03227 .32659 L
.03958 .30648 L
.04792 .28871 L
.0716 .25163 L
.08726 .23308 L
.103 .21747 L
.12293 .20108 L
.14183 .18841 L
.15916 .17892 L
.17816 .17064 L
.18868 .16697 L
.19834 .16416 L
.20807 .16186 L
.21722 .16019 L
.226 .15903 L
.23543 .15828 L
Mistroke
.24391 .15805 L
.25165 .15822 L
.25987 .15881 L
.26878 .15994 L
.27318 .16069 L
.27787 .16164 L
.28619 .16372 L
.30093 .16871 L
.31552 .17552 L
.32717 .18253 L
.33896 .19136 L
.35149 .20316 L
.3619 .21556 L
.37211 .23116 L
.37965 .24635 L
.3852 .26142 L
.38894 .27577 L
.39035 .28341 L
.39148 .29188 L
.39188 .29616 L
.39219 .30077 L
.3924 .30911 L
.3922 .31698 L
.39192 .32146 L
.39154 .32566 L
.39044 .33407 L
.38963 .33876 L
.38877 .34305 L
.38479 .3579 L
.37907 .37302 L
.37106 .3887 L
.36201 .40233 L
.35039 .41603 L
.33612 .42898 L
.32226 .43864 L
.30585 .44725 L
.29788 .4505 L
.28916 .45345 L
.28141 .45557 L
.27287 .4574 L
.26443 .45871 L
.25656 .45951 L
.24853 .45993 L
.24079 .45995 L
.2317 .45952 L
.22318 .45868 L
.21375 .45727 L
.20363 .45519 L
.18399 .4495 L
.16329 .4411 L
Mistroke
.14585 .432 L
.12718 .42003 L
.10788 .40489 L
.08846 .38625 L
.05807 .34699 L
.04614 .32584 L
.04072 .31424 L
.03569 .30164 L
.03196 .29045 L
.0286 .27794 L
.02628 .26645 L
.02477 .25562 L
.02395 .24493 L
.02384 .2337 L
.02439 .22417 L
.0257 .21384 L
.02798 .20284 L
.02967 .19678 L
.03146 .19133 L
.03571 .18091 L
.04061 .17145 L
.05314 .1537 L
.06138 .14497 L
.07151 .13622 L
.0836 .12783 L
.09654 .12071 L
.10941 .11507 L
.12484 .10982 L
.14092 .10577 L
.15669 .10298 L
.17638 .10084 L
.1964 .1 L
.21637 .10028 L
.23587 .10152 L
.25862 .10402 L
.28416 .10803 L
.31418 .11417 L
.34328 .12144 L
.41505 .14408 L
.56843 .21012 L
.79035 .3365 L
Mfstroke
.79035 .3365 m
1 .48262 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[24]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O0?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX00?m[FR5[FP0001m[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`050000nf]jJeX006]JJgY[
FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/00F]J000QJeX00`00JeY[FP06JeX00`00JeX0003cJeX0000KKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j00<0000DJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FP80003[Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000QJeX00`00JeY[FP06JeX20006JeX00`00JeY[FP3[
JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000PJeX20008JeX30005
JeX00`00JeY[FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000b
JeX00`00JeY[FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000b
JeX00`00JeY[FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000b
JeX00`00JeY[FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000b
JeX00`00JeY[FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000b
JeX00`00JeY[FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000b
JeX00`00JeY[FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000b
JeX00`00JeY[FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000b
JeX00`00JeY[FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000b
JeX00`00JeY[FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000b
JeX00`00JeY[FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000b
JeX00`00JeY[FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000b
JeX00`00JeY[FP0@003KJeX0000`Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J1@00
011[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N``0003>JeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00;6]J10000V]J00<006]JJeX076]J1P00
bF]J0000:6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J100002][NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`04
0000a6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000UJeX3000:JeX00`00JeY[FP0V
JeX40031JeX0000SKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000>V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j10000;a[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000QJeX2000?JeX0
0`00JeY[FP0^JeX3002jJeX0000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0004E[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX00`000;I[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J
000NJeX00`00JeY[FP0AJeX00`00JeY[FP0dJeX4002ZJeX00`00JeY[FP06JeX0000LKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000Cf]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk00<0002UKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk00800008JeY_Nf]JJgY[FVmkJeY[NP5[FP006f]J00<006]JJeX056]J00<006]JJeX0>f]J
0`00XF]J00<006]JJeX02F]J00006F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0080001HJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/40000Z6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00
66]J00<006]JJeX05f]J00<006]JJeX0@V]J0`00Uf]J0P003F]J0000NVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000XfmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j005[FP005f]J00<006]JJeX066]J00<006]JJeX0Af]J0P00TF]J00<0
06]JJeX03V]J0000OV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP<0002<JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP80000@JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX001E[FP03001[
FV]J01Y[FP03001[FV]J00m[FP/0039[FP8008U[FP03001[FV]J015[FP0003m_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX01@0000]_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j00D0000_Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP020000VV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j0F]J000DJeX00`00JeY[FP0KJeX00`00JeY[FP05JeX5000EJeX3000^JeX3
0021JeX2000EJeX0000hJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[
NV]JKg][FP80000MKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`030000;VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0P0009E_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP004V]J
00<006]JJeX07F]J00@006]JJeY[FP80029[FP8002i[FP8007][FP03001[FV]J01I[FP0003A_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FP80000VJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP80000^JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX30000MV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0P0001Q[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0015[FP03001[FV]J01i[FP8002Y[FP80
02m[FP8007=[FP03001[FV]J01U[FP00031[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX30000GV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j0P0008a[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
0F]J000@JeX00`00JeY[FP0KJeX20002JeX00`00JeY[FP0/JeX2000`JeX3001[JeX2000MJeX0002F
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
0P0008M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000?JeX00`00JeY[FP0IJeX20005
JeX00`00JeY[FP0_JeX00`00JeY[FP0aJeX2001UJeX00`00JeY[FP0NJeX0001UJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP020000<f]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP03
0000H6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP80000PJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP003f]J00<006]JJeX05f]J00<006]JJeX01V]J00<0
06]JJeX0<V]J00<006]JJeX0<f]J0P00GF]J00<006]JJeX08F]J00009fmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP020000MV]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j0P0007i[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX000i[FP03001[FV]J01E[FP03001[FV]J00U[FP03001[FV]J
03=[FP03001[FV]J03I[FP8005I[FP8002E[FP0002A[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000OFmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
0P0007Y[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk0F]J000>JeX00`00JeY[FP0BJeX00`00JeY[FP0<JeX00`00JeY[FP0dJeX00`00JeY[
FP0iJeX2001@JeX00`00JeY[FP0VJeX0002WKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
06]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP020000C6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0P0002Q[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP5[FP003V]J00<006]JJeX046]J00<006]JJeX03V]J00<006]JJeX0=V]J00<006]JJeX0>f]J
00<006]JJeX0B6]J00<006]JJeX0:F]J0000ZV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeX20000Lf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk005[FP003V]J00<006]JJeX03V]J00<006]JJeX046]J00<006]JJeX0=f]J00<006]JJeX0?F]J
0P00@f]J0P00;F]J0000[VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP80001_Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP003V]J
00<006]JJeX036]J00<006]JJeX04V]J00<006]JJeX0>6]J00<006]JJeX0@6]J00<006]JJeX0?6]J
00<006]JJeX0;V]J0000/F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP020000>V]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j0P00031[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX000i[
FP03001[FV]J00][FP03001[FV]J01=[FP03001[FV]J03U[FP03001[FV]J049[FP8003M[FP03001[
FV]J035[FP000;E_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_N`020000J6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX000i[FP03001[
FV]J00U[FP03001[FV]J01E[FP03001[FV]J03Y[FP03001[FV]J04E[FP80031[FP8003E[FP000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_N`02JeX000i[FP03001[FV]J00Q[FP03001[
FV]J01I[FP03001[FV]J03][FP03001[FV]J04M[FP8002Y[FP8003Q[FP000;a_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J0P0002I[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P0003U[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000>JeX00`00JeY[FP07JeX00`00JeY[FP0GJeX00`00
JeY[FP0lJeX00`00JeY[FP0FJeX50002JeX00`00JeY[FP02JeX00`00JeY[FP0UJeX2000SJeX00`00
JeY[FP0:JeX2000^JeX0003QJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]j
JeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00
JeY_Nf]JJgY[FVmkJeY[NP00Kg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080000lJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000?
JeX00`00JeY[FP05JeX00`00JeY[FP0HJeX00`00JeY[FP0lJeX00`00JeY[FP0HJeX00`00JeY[FP08
JeX00`00JeY[FP0WJeX2000MJeX00`00JeY[FP0>JeX00`00JeY[FP0/JeX0002EKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_N`020000;6]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX200006F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J0080000oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP003f]J00<006]JJeX00f]J00<006]JJeX06V]J
00<006]JJeX0?6]J00<006]JJeX066]J00<006]JJeX01V]J00<006]JJeX0;F]J0P005F]J0P004V]J
00<006]J0000;F]J0000Rf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk00800008
JeY_Nf]JJgY[FVmkJeY[NP<00027JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP0046]J
00D006]JJeY[FP0001e[FP03001[FV]J03e[FP03001[FV]J05=[FP8000m[FP8004E[FP000<Y_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80000;Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP020000AV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000AJeX00`00JeX0000NJeX00`00JeY[
FP0mJeX00`00JeY[FP1GJeX20008JeX00`00JeY[FP17JeX0000AJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP020000`F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J00800019Kg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/00F]J000AJeX2000OJeX00`00JeY[FP0mJeX00`00JeY[FP1JJeX20000
0f]J0000001<JeX00007Kg][FV]jJeY_Nf]JJgX0o`004P0000M_Nf]JJgY[FVmkJeY[NP01JeX0015[
FP8001m[FP03001[FV]J03e[FP03001[FV]J01e[FP03001[FV]J03Y[FP80009[FP8001e[FP03001[
FV]J02][FP000=E[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_N`00JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J001[FV]jJeY_Nf]JJgX00P0004Q[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX0015[FP03001[
FP0001i[FP03001[FV]J03e[FP03001[FV]J05M[FP8000U[FP03001[FV]J04I[FP000<Y_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80000<Kg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J0P0004E[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000@JeX01@00JeY[FV]J00007F]J00<006]J
JeX0?F]J00<006]JJeX0E6]J00<006]JJeX03V]J0P00A6]J0000af]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J001[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk0080000CJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX00P00045_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk005[FP003f]J00<006]JJeX00f]J00<006]JJeX06V]J00<006]JJeX0
?6]J00<006]JJeX0DF]J0P005f]J00<006]JJeX0?f]J0000gfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j0080000nJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NP5[FP003f]J00<006]JJeX016]J00<006]JJeX06F]J00<006]JJeX0?6]J00<0
06]JJeX0CV]J0P007F]J00<006]JJeX0?6]J0000`6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80001M
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk005[FP003V]J00<006]JJeX01f]J00<006]JJeX05f]J00<006]JJeX0>f]J00<006]JJeX0
C6]J00<006]JJeX08F]J0P00>f]J0000_FmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][
FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`020000H6]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP5[FP003V]J00<006]JJeX026]J00<006]JJeX05V]J00<006]JJeX0>f]J00<006]JJeX0BF]J00<0
06]JJeX09f]J0P00>6]J0000^V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[
NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX0
06]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80001SJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP00
3V]J00<006]JJeX02V]J00<006]JJeX056]J00<006]JJeX0>V]J00<006]JJeX0AV]J0P00;f]J0P00
=F]J0000]VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX20000IfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP003V]J00<006]JJeX0
2f]J00<006]JJeX04f]J00<006]JJeX0>F]J00<006]JJeX0@f]J0P00=V]J00<006]JJeX0<F]J0000
/V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
06mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P00
03U[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00P00
031[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX000i[FP03001[FV]J00e[FP03
001[FV]J015[FP03001[FV]J03Q[FP03001[FV]J041[FP8003e[FP03001[FV]J02i[FP000:i_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000@6mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P00
02e[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000>JeX00`00JeY[FP0>JeX00`00JeY[
FP0@JeX00`00JeY[FP0gJeX00`00JeY[FP0mJeX20014JeX00`00JeY[FP0[JeX0002ZJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP800017JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02
0000:V]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP003V]J00<006]JJeX046]J00<006]JJeX03V]J
00<006]JJeX0=V]J00<006]JJeX0>V]J0P00Bf]J00<006]JJeX0:6]J0000YVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J0P0007M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX0
06]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP003V]J00<006]JJeX04V]J00<006]JJeX036]J00<006]J
JeX0=F]J00<006]JJeX0=f]J0P00DF]J0P009f]J0000XV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP80
001kJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk005[FP003V]J00<006]JJeX056]J0P002f]J00<006]JJeX0<f]J00<006]JJeX0=F]J
0P00F6]J0P0096]J0000WVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX20000OfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP003f]J
00<006]JJeX05V]J0P0026]J00<006]JJeX0<F]J00<006]JJeX0<f]J0P00Gf]J0P008F]J0000VV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J0P0008=[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP0046]J00<006]JJeX066]J0P001F]J
00<006]JJeX0;f]J00<006]JJeX0<F]J0P00IV]J00<006]JJeX07F]J0000;FmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`020000If]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0080001YKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080000LJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX0011[FP03001[FV]J01a[FP04001[FV]J000_JeX0
0`00JeY[FP0_JeX2001]JeX00`00JeY[FP0JJeX0000`JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J0`0002e[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX00P00031_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000L6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]J0P0001U_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`01JeX0015[FP03001[FV]J01i[FP8002][FP03001[FV]J02i[FP8007A[FP03001[
FV]J01M[FP0003A_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FP80000W
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk0080000_JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP02
0000MfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX00P0001I[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP004V]J
00<006]JJeX07F]J00@006]JJeY[FP8002=[FP8002m[FP8007][FP03001[FV]J01A[FP0003Q[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J0`0001e[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J00<0000^JeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX30000Tf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX001=[FP03001[FV]J01a[FP03001[FV]J00I[
FP8001U[FP8002m[FP80089[FP8001=[FP0003e_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_N`0600003V]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/50000;V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0`0009Q[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000EJeX0
0`00JeY[FP0JJeX00`00JeY[FP0>JeX>000`JeX3002:JeX2000@JeX0001oJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/0
0P0009i[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000GJeX00`00JeY[FP0HJeX00`00JeY[FP17JeX3002BJeX2
000=JeX0001iKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/00`000:=_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX001Q[FP03001[FV]J
01M[FP03001[FV]J049[FP8009][FP03001[FV]J00U[FP0007A[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J0`0009i[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0P0000Q[FV]j
JeY_Nf]JJgY[FVmk0F]J000JJeX2000FJeX00`00JeY[FP0kJeX4002SJeX00`00JeY[FP06JeX0000L
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX20000
Cf]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk00<0002_Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000NJeX2000BJeX00`00JeY[FP0e
JeX3002cJeX0001VJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J10000;E_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX0025[FP8000m[FP03
001[FV]J02i[FP<00;Y[FP0002=_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080000jJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX40000_6]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX1JeX002E[
FP8000][FP03001[FV]J02I[FP@00<5[FP0002M[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P0002i[FVmkJeY[
NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`@00034JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg/1JeX002U[FP@000E[FP03001[FV]J01e[FPD00<U[FP0002e_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/02@0000m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/03@000<e[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX0039[FP04001[FV]JJeX?
003KJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000bJeX00`00JeY[
FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000bJeX00`00JeY[
FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000bJeX00`00JeY[
FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000bJeX00`00JeY[
FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000bJeX00`00JeY[
FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000bJeX00`00JeY[
FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000bJeX00`00JeY[
FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000bJeX00`00JeY[
FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000bJeX00`00JeY[
FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000bJeX00`00JeY[
FP3[JeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000bJeX00`00JeY[
FP3[JeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000bJeX00`00JeY[
FP3[JeX0000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/01@000?][NV]J001[FV]jJeY_N`00JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP008F]J00<006]JJeX01V]J
00<006]J00001F]J00<006]JJeX0jf]J0000<VmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeX20000jfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j005[FP008F]J00<006]JJeX01V]J0P00m6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FP00
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmk009[FP0086]J0P0026]J0`00lf]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j009[FP00\
\>"],
  ImageRangeCache->{{{134.875, 421.875}, {339, 162.063}} -> {-2.88649, 
  1.31466, 0.0155999, 0.0178639}}]
}, Open  ]],

Cell[TextData[{
  StyleBox[
  "The segment of the curve suggests that the criterion is fulfilled what \
really has been demonstrated in Section 3. There we also saw that the \
polynomial "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`p\_9\)]]],
  StyleBox[
  " was unstable. The amplitude-phase diagram of that polynomial can be \
plotted in a similar way."]
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ParametricPlot[{Re[p\_9[I\ t]], Im[p\_9[I\ t]]}, {t, \(-3.7\), 3.7}, 
      PlotRange \[Rule] {\(-1.5\), 1.5}, 
      Ticks \[Rule] {{\(-0.5\), 0.5}, {\(-1.5\), 1.5}}, 
      Prolog \[Rule] {Text["\<t=3.6\>", {1.5, 1.2}], 
          Text["\<t=-3.6\>", {1.5, \(-1.2\)}], PointSize[0.015], 
          Point[{Re[p\_9[3.6  I]], Im[p\_9[3.6  I]]}], 
          Point[{Re[p\_9[\(-3.6\) I]], Im[p\_9[\(-3.6\) I]]}]}]; \)\)], 
  "Input",
  CellLabel->"In[25]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.217067 0.386518 0.309017 0.206011 [
[.02381 .29652 -12 -9 ]
[.02381 .29652 12 0 ]
[.41033 .29652 -9 -9 ]
[.41033 .29652 9 0 ]
[.20457 0 -24 -4.5 ]
[.20457 0 0 4.5 ]
[.20457 .61803 -18 -4.5 ]
[.20457 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 .30902 m
.02381 .31527 L
s
[(-0.5)] .02381 .29652 0 1 Mshowa
.41033 .30902 m
.41033 .31527 L
s
[(0.5)] .41033 .29652 0 1 Mshowa
0 .30902 m
1 .30902 L
s
.21707 0 m
.22332 0 L
s
[(-1.5)] .20457 0 1 0 Mshowa
.21707 .61803 m
.22332 .61803 L
s
[(1.5)] .20457 .61803 1 0 Mshowa
.21707 0 m
.21707 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
gsave
.79684 .55623 -78 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3.6) show
93.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
gsave
.79684 .0618 -81 -11.5 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(t) show
69.000000 14.437500 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(=) show
75.000000 14.437500 moveto
(-) show
81.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(3.6) show
99.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math1Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math1Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math1Mono
%%+ font Courier
grestore
.015 w
.80396 .48677 Mdot
.80396 .13126 Mdot
.5 Mabswid
.97619 .09549 m
.73172 .1448 L
.52143 .1781 L
.42888 .18919 L
.35293 .19614 L
.31356 .19881 L
.28034 .20049 L
.26299 .20112 L
.25413 .20138 L
.24497 .20159 L
.23714 .20172 L
.23276 .20178 L
.22871 .20182 L
.22172 .20186 L
.21785 .20187 L
.21436 .20187 L
.20762 .20184 L
.20141 .20177 L
.19593 .20169 L
.19013 .20157 L
.18391 .20141 L
.1775 .20121 L
.1664 .20075 L
.14772 .19967 L
.13779 .19891 L
.12894 .19811 L
.11041 .19599 L
.09527 .19373 L
.07981 .19078 L
.06707 .18767 L
.04817 .18128 L
.04082 .17779 L
.03432 .17379 L
.03007 .17028 L
.0283 .16842 L
.02676 .16643 L
.02568 .16467 L
.02521 .16374 L
.02478 .16274 L
.02446 .16182 L
.02422 .16098 L
.02404 .16013 L
.02391 .15934 L
.02383 .15841 L
.02381 .15742 L
.02386 .15649 L
.02395 .15563 L
.02413 .15463 L
.02441 .15355 L
.02474 .15252 L
Mistroke
.02512 .15157 L
.02616 .1495 L
.02735 .14763 L
.03085 .1435 L
.03475 .14001 L
.03983 .13633 L
.05117 .12996 L
.06601 .1237 L
.08518 .11757 L
.10796 .11212 L
.13136 .10801 L
.14357 .10635 L
.15726 .10484 L
.17054 .10371 L
.17698 .10327 L
.18308 .10292 L
.18906 .10263 L
.19457 .10241 L
.20073 .10223 L
.20399 .10216 L
.20742 .1021 L
.21056 .10206 L
.21392 .10204 L
.2171 .10203 L
.21999 .10204 L
.22341 .10206 L
.22534 .10208 L
.22712 .1021 L
.2304 .10216 L
.23387 .10224 L
.24098 .10245 L
.24775 .10273 L
.26047 .10342 L
.27422 .10443 L
.2892 .10585 L
.31606 .10922 L
.3407 .11328 L
.39134 .1248 L
.41887 .13307 L
.44359 .14192 L
.48947 .16279 L
.52587 .18509 L
.55654 .2105 L
.57072 .22589 L
.58174 .24074 L
.59097 .25681 L
.5946 .26485 L
.59741 .27232 L
.59947 .27902 L
.60126 .28644 L
Mistroke
.60194 .29004 L
.60255 .29392 L
.60282 .29606 L
.60303 .29802 L
.6032 .29987 L
.60335 .30187 L
.60347 .30393 L
.60354 .30587 L
.60358 .30777 L
.60358 .30951 L
.60356 .31139 L
.6035 .31346 L
.60345 .31451 L
.60339 .31562 L
.60325 .31764 L
.60287 .32157 L
.60238 .32529 L
.60112 .33223 L
.59907 .34042 L
.59662 .34794 L
.58917 .36476 L
.5803 .37944 L
.57013 .39286 L
.54056 .42179 L
.50358 .44735 L
.46358 .46781 L
.41762 .48538 L
.38942 .49376 L
.3629 .50025 L
.33692 .50544 L
.3083 .5099 L
.29245 .51184 L
.27781 .51329 L
.26383 .51439 L
.25625 .51487 L
.24907 .51525 L
.24243 .51553 L
.23893 .51565 L
.23522 .51576 L
.23179 .51584 L
.22869 .5159 L
.22558 .51595 L
.22266 .51598 L
.21923 .516 L
.21563 .516 L
.21256 .51599 L
.20921 .51596 L
.2056 .51591 L
.20176 .51583 L
.19487 .51563 L
Mistroke
.18852 .51538 L
.18167 .51504 L
.16942 .51424 L
.15772 .51323 L
.14717 .51211 L
.12382 .50884 L
.10343 .50496 L
.08303 .49986 L
.06376 .49349 L
.04852 .48675 L
.04177 .48295 L
.03565 .47874 L
.03089 .47458 L
.02758 .47073 L
.02634 .46884 L
.02526 .46679 L
.02487 .46585 L
.02452 .46485 L
.02425 .46392 L
.02406 .46305 L
.02391 .46208 L
.02386 .46156 L
.02382 .46102 L
.02381 .4601 L
.02387 .45909 L
.02399 .45819 L
.02418 .45723 L
.02443 .45631 L
.02471 .45548 L
.02555 .4536 L
.02679 .45156 L
.02845 .44944 L
.03035 .44749 L
.03475 .44394 L
.03981 .4408 L
.05499 .43413 L
.06491 .43097 L
.07709 .42786 L
.08905 .4254 L
.10345 .42301 L
.12073 .42079 L
.13869 .41905 L
.15052 .41818 L
.16237 .41748 L
.17355 .41697 L
.18012 .41674 L
.18631 .41655 L
.19237 .41641 L
.19892 .41629 L
.20563 .41621 L
Mistroke
.20951 .41618 L
.21316 .41617 L
.21991 .41616 L
.22618 .41619 L
.22969 .41622 L
.23355 .41626 L
.24068 .41637 L
.24715 .41649 L
.25442 .41667 L
.26955 .41713 L
.29817 .41837 L
.33375 .4205 L
.37504 .42369 L
.4579 .43204 L
.65481 .45992 L
.91406 .50911 L
.97619 .52255 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00O0?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX00?m[FR5[FP00039[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]J1@000>Q[FV]j001_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`5[FP00=6]J00<006]JJeX01V]J00<006]J0000h6]J0000;VmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]J0`0001A[FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[
FVmk0`000=M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j005[FP00=6]J00<006]JJeX01V]J0P001V]J00<006]JJeX0f6]J0000
of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00<f]J0P0026]J0`001F]J00<0
06]JJeX0f6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<0
06]JJeX0f6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<0
06]JJeX0f6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<0
06]JJeX0f6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<0
06]JJeX0f6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<0
06]JJeX0f6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<0
06]JJeX0RV]J0P000f]J100026]J0P0016]J00@006]JJeY[FP80035[FP000=e_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J001[FV]jJeY_
Nf]JJgY[FVmk00@0000nJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk001[NP00Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00AF]J00<006]JJeX0RF]J00<006]JJeX00f]J10002F]J00<0
06]JJeX01V]J00<006]J0000<6]J0000d6]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]J100001U[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001_Nf]JJgY[FVmkJeY[NP020000<6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[
FP00AF]J00<006]JJeX0RF]J00<006]JJeX03f]J00<006]J00001f]J00<006]JJeX0<6]J0000kVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J0P0002m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00AF]J00<006]JJeX0f6]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<006]JJeX0f6]J0000ofmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<006]JJeX0f6]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`004V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FP<0000;JgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX004E[FP03001[FV]J0<A[FPD000m[
FP0003M_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP0O0000
/F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP050000
4fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP00;F]J2P003V]J00<006]J
JeX03V]J1P00YV]J1@006F]J0000:F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0100002m[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J00L0002JJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX500007FmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J000UJeX4000LJeX00`00
JeY[FP0KJeX6002?JeX5000SJeX0000PKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FPD00014JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`@00026JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NPD0000WKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j005[FP007V]J0P009F]J
00<006]JJeX09F]J1@00Nf]J1P00;F]J00006f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`030000E6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP@0001bKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]J1@00039[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000H
JeX3000ZJeX00`00JeY[FP0^JeX4001YJeX5000hJeX0000FKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX20000HVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX30000HF]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
00P0000iJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
005[FP005F]J00<006]JJeX0;F]J00<006]JJeX0=F]J0P00FV]J1@001V]J00<006]JJeX0>F]J0000
4f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080001ZJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/20000Df]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeX01@0004I[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`5[FP004V]J00<006]JJeX0<6]J00<006]J
JeX0>F]J0`00BV]J1P00C6]J0000Q6mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP800012JgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]J1P00055[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000AJeX0
0`00JeY[FP0aJeX00`00JeY[FP0nJeX3000iJeX6001HJeX0000@JgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeX20000MfmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX00`0002m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk00L0001M
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk005[FP0046]J00<006]JJeX0<V]J00<006]JJeX0A6]J0P009f]J1P00IF]J000046mkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P0007a[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80000OKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX01P0006Y[FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP004F]J00<006]JJeX0<F]J00<006]JJeX0B6]J0P00
5V]J1`00LF]J0000TV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeX200003V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX60000Mf]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00F]J000CJeX00`00JeY[FP0_
JeX00`00JeY[FP1<JeX00`00JeY[FP05JeX6001nJeX0000DKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FP80001nJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J200008=_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
005[FP005V]J0`00;6]J00<006]JJeX0A6]J20000f]J0P00Qf]J00006F]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0080001XJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`T0002CJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk005[FP006f]J0`009f]J00<006]JJeX0<V]J2@005f]J00<006]JJeX0Pf]J00007VmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP@0001>
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J2P000:E[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX00F]J000RJeX9000JJeX00`00JeY[FP0MJeX;000/JeX00`00JeY[FP21JeX0000[
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/02P0002I[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk2P0003Q[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0P00081[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk0F]J000eJeXV0014JeX00`00JeY[FP1nJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgX00V]J0015JeX00`00JeY[FP1IJeX00`00JeY[FP1lJeX0003oJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J0015JeX00`00JeY[FP1KJeX00`00JeY[FP1jJeX0003o
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J0015JeX00`00JeY[FP1MJeX00`00
JeY[FP1hJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J0015JeX00`00
JeY[FP1OJeX00`00JeY[FP1fJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
0V]J0015JeX00`00JeY[FP1PJeX00`00JeY[FP1eJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/00V]J0015JeX00`00JeY[FP1QJeX00`00JeY[FP1dJeX0003oKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J0015JeX00`00JeY[FP1RJeX00`00JeY[FP1cJeX0003o
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J0015JeX00`00JeY[FP1SJeX00`00
JeY[FP1bJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J000=JeX00`00
JeY[FP02JeX00`00JeY[FP02JeX00`00JeY[FP0[JeX00`00JeY[FP0/JeX00`00JeY[FP02JeX00`00
JeY[FP02JeX00`00JeY[FP0[JeX00`00JeY[FP1aJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
001[FP00JeY[NV]JKg][FV]jJeX006]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]j001_Nf]JJgY[FVmkJeY[NP00Kg/006]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FP00JeY[NV]JKg][FV]jJeX006]J001[
FVmkJeY[NV]JKg/00V]J0007JeX30002JeX00`00JeX00009JeX00`00JeY[FP0ZJeX00`00JeY[FP0[
JeX00`00JeX00009JeX00`00JeY[FP0[JeX00`00JeY[FP1`JeX0000FKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]J001[FP00JeY_Nf]JJgY[FVmkJeX20000IFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_N`00JgY[FVmkJeY[NV]JKg/00P000:1[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP0036]J00<006]J00001f]J00<006]JJeX0;6]J00<006]JJeX0
:f]J00<006]J00001f]J00<006]JJeX0;F]J00<006]JJeX0L6]J00005V]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]J0`0006A[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NP<0002OJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk005[FP00AF]J00<006]JJeX0IF]J00<006]JJeX0L6]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<006]JJeX0IV]J00<006]JJeX0Kf]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<006]JJeX0IV]J
00<006]JJeX0Kf]J00002VmkJeY[NV]JKg][FV]jJeY_Nf]Jo`004P0000A[FVmkJeY[NP5[FP0046]J
00<006]JJeX0<V]J00<006]JJeX0<F]J00<006]JJeX0<V]J00<006]JJeX0Kf]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<006]JJeX0IV]J00<006]JJeX0Kf]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<006]JJeX0IF]J
00<006]JJeX0L6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J
00<006]JJeX0IF]J00<006]JJeX0L6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
7fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j009[FP00AF]J00<006]JJeX0IF]J00<006]JJeX0L6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<006]JJeX0I6]J00<006]JJeX0LF]J0000ofmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<006]JJeX0Hf]J00<006]JJeX0LV]J
0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<006]JJeX0HV]J
00<006]JJeX0Lf]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J
00<006]JJeX0HF]J00<006]JJeX0M6]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
7f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk009[FP00AF]J00<006]JJeX0H6]J00<006]JJeX0MF]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<006]JJeX0GV]J00<006]JJeX0Mf]J0000of]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J00<006]JJeX0GF]J00<006]JJeX0N6]J
0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX006]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP007fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j009[FP00AF]J00<006]JJeX0Ff]J
00<006]JJeX0NV]J0000of]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`007f]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk009[FP00AF]J
00<006]JJeX0FF]J00<006]JJeX0O6]J0000ofmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00
7fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j009[FP00>6]J7`00B6]J00<006]JJeX0OV]J0000:F]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX03`00
01m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`0D0000]6]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP00JeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`5[FP009F]J100076]J00<006]JJeX08f]J2`009f]J00<006]JJeX0P6]J00007Vmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FPL0
001AJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J00/0000JJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP800022JeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX1JeX001][FP<002M[FP03001[FV]J03U[FPT0011[FP03001[FV]J08=[FP0001U[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP020000Kf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FP070000SV]JKg][FV]jJeY_Nf]JJgX006mk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000GJeX2000/JeX00`00JeY[FP19JeX80027JeX0000E
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk0080001oJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeX02000085[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000CJeX2000`JeX00`00JeY[FP1<JeX20008JeX7
001kJeX0002BJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FP80000AJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP070000Lf]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk005[FP004F]J00<006]JJeX0<F]J00<0
06]JJeX0B6]J0P006V]J1P00KV]J000046mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J0P00
07a[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FP80000RKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX70000IV]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP0046]J
00<006]JJeX0<V]J00<006]JJeX0A6]J0P00:f]J1P00HF]J000046]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]J0P0007Q_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX0
06mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeX20000<f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_N`060000FV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`5[FP004F]J00<006]JJeX0<F]J00<006]JJeX0?f]J0`00>f]J1@00EV]J0000QFmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk00800013JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX01@00051[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j0F]J000BJeX00`00JeY[FP0`JeX00`00JeY[FP0j
JeX3001:JeX6001;JeX0000CJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00P00
06Y[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`<0001CKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP050000AFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX001E[FP03
001[FV]J02e[FP03001[FV]J03E[FP8005][FPD0045[FP0001I_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FP80001RKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP<0001RJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NPL0000iJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j005[FP0066]J0P00:f]J00<006]JJeX0;V]J1000JF]J1`00=V]J00006V]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeX30000EV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/30000M6mkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeX006]JKg][FV]jJeX60000;f]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg/00F]J000MJeX2000VJeX00`00JeY[FP0WJeX4001mJeX5000[JeX0000OKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX01000
04M[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_N`00JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J00D00026JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`D0
000UJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX00F]J000SJeX6000LJeX00`00JeY[FP0LJeX6002@JeX6000PJeX0000Y
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NP060000<F]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]J00@0002LJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J1@0001Y[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmk0F]J000_JeX5000AJeX00`00JeY[FP0@JeX8002UJeX4000GJeX0
000dKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeXT0000/FmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`0400004V]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP5[FP00AF]J00<006]JJeX0aF]J10003f]J0000of]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`004V]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FP<0000;JgY[FVmkJeY[NV]JKg][FV]jJeY_N`01JeX004E[FP03001[FV]J0=Q[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX004E[FP03001[FV]J0=Q[FP000?m[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX004E[FP03001[FV]J0=Q[FP000?m_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX004E[FP03001[FV]J08e[FP8000=[
FP@0009[FP8000A[FP04001[FV]JJeX2000dJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j001_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FP00JeY_N`00JgY[FVmkJeY[NV]JKg][
FV]jJeX006]JJgY[FVmkJeY[NV]J001[FP00JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmk000OJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/00V]J0015JeX00`00JeY[FP2<JeX00`00JeY[FP03JeX40003JeX00`00JeY[FP06JeX0
0`00JeX0000cJeX0003CKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk001[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgX0100001=[FVmkJeY[NV]JKg][FV]jJeY_Nf]J001[FVmkJeY[NV]JKg][
FP020000<fmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP01JeX004E[FP03
001[FV]J08a[FP03001[FV]J00U[FP03001[FP0000M[FP03001[FV]J03=[FP000>][NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_N`020000<V]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/1JeX004E[FP03001[FV]J0=Q[FP000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX004E[FP03001[FV]J0=Q[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX004E[FP03001[FV]J0=Q[FP000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX004E[FP03001[FV]J0=Q[FP000?m[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg/001m[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_N`02JeX004E[FP03001[FV]J0=Q[FP000?m_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg/006]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgX001m_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NP02JeX004E[FP03001[FV]J0=Q[FP00039[NV]JKg][FV]j
JeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk
JeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J1@000>Q[FV]j001_Nf]JJgY[FP00JeY[NV]JKg][
FV]j001_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_N`5[FP00=6]J00<006]JJeX01V]J00<006]J00001F]J00<006]JJeX0
f6]J0000AFmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J001[FV]jJeY_
Nf]JJgY[FVmkJeY[NP00Kg][FV]jJeY_N`030000efmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_
Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[
NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00F]J000dJeX00`00JeY[FP06
JeX2003QJeX0003oJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeX006]J
Kg][FV]jJeY_Nf]JJgX006mkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmk000OJgY[FVmkJeY[NV]JKg][
FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg/00V]J000cJeX20008
JeX3003PJeX0003oKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]J
Kg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]J
JgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]j000OKg][FV]jJeY_Nf]JJgY[
FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgY[FVmkJeY[NV]JKg][FV]jJeY_Nf]JJgX00V]J0000\
\>"],
  ImageRangeCache->{{{134.875, 421.875}, {688.313, 511.375}} -> {-1.94482, 
  7.55474, 0.00952131, 0.0178639}}]
}, Open  ]],

Cell[TextData[StyleBox[
"No one-liner is supplied for this method because the appropriate parameter \
domains can only be found by trial and error."]], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[
  "Theorem 1 can also be translated into the language of algebra. It is easy \
to see that the curve "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_p\)]]],
  StyleBox[
  " is symmetrical to the real axis. A corllary of this fact is that one can \
work with polynomials of half the original degree."]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  "Let us suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`N > 2\)]],
  " and let us introduce two polynomials for positive arguments in the \
following way:"
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(G(t\^2) := Re(p(i\ t))\), ",", 
        StyleBox[
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontColor->GrayLevel[0]], "    "}]],
          FontColor->GrayLevel[0]], 
        RowBox[{
          StyleBox[\(H(t\^2)\),
            FontColor->GrayLevel[0]], ":=", 
          \(\(Im(p(i\ t))\)/t\ \ \ \ \ 
            \((t\ \[Epsilon]\ \[DoubleStruckCapitalR])\)\)}]}], 
      TraditionalForm]]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["The next statement is called "],
  StyleBox["Hermite's criterion",
    FontSlant->"Italic"],
  StyleBox[" or "],
  StyleBox["Mikhajlov's criterion",
    FontSlant->"Italic"],
  StyleBox[" (see e.g. [4, p. 48])."]
}], "Text",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theorem 2", "Subsubsection"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      \(TraditionalForm\`N > 2\)]],
  ". Then the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " in ",
  StyleBox["(1) ",
    FontSlant->"Plain"],
  "is stable if and only if ",
  Cell[BoxData[
      \(TraditionalForm\`\(a\_N\) a\_\(N - 1\) > 0\)]],
  " and the roots ",
  Cell[BoxData[
      \(TraditionalForm\`g\_1, \(g\_\(2, \)\) \[CenterEllipsis], \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h\_1, h\_2, \[CenterEllipsis]\)]],
  " of the polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " respectively are all positive and they alternately follow each other \
starting with ",
  Cell[BoxData[
      \(TraditionalForm\`g\_1\)]],
  ", i.e. "
}], "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`0 < g\_1 < h\_1 < g\_2 < h\_2 < \[CenterEllipsis]\)]]], "DisplayFormula",\

  FontWeight->"Plain"],

Cell[TextData[StyleBox[
"This theorem makes obviously possible to write a code which generally works \
faster then the one above. We are going however to state such theorems below \
which can serve as bases of much more efficient codes."]], "Text",
  FontWeight->"Plain"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5 THE ROUTH\[Dash]HURWITZ CRITERION"]], "Section"],

Cell[TextData[{
  "The best known criterion of stability is called the ",
  StyleBox["Routh\[Dash]Hurwitz ",
    FontSlant->"Italic"],
  "(sometime only ",
  StyleBox["Hurwitz",
    FontSlant->"Italic"],
  ") ",
  StyleBox["criterion, ",
    FontSlant->"Italic"],
  "although the criterion given by Routh (1875) was different from the one \
below. (Later, we shall present another criterion which is much closer to \
Routh's original work.) The Routh\[Dash]Hurwitz criterion has essentially \
been discovered by  Hurwitz",
  StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]],
  " (1895), a student of Stodola, independently from Routh."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["The "],
  StyleBox["Routh\[Dash]Hurwitz matrix ",
    FontSlant->"Italic"],
  StyleBox["of polynomial (1) is defined as follows:"]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["RH",
            FontSlant->"Italic"], "(", "p", ")"}], ":=", 
        RowBox[{"(", GridBox[{
              {\(a\_1\), \(a\_0\), "0", "0", "0", "\[CenterEllipsis]", "0", 
                "0", "0", "0"},
              {\(a\_3\), \(a\_2\), \(a\_1\), \(a\_0\), "0", 
                "\[CenterEllipsis]", "0", "0", "0", "0"},
              {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                "\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                "\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                "\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                "\[VerticalEllipsis]", "\[VerticalEllipsis]"},
              {"0", "0", "0", "0", "0", "0", "0", \(a\_N\), \(a\_\(N - 1\)\), 
                \(a\_\(N - 2\)\)},
              {"0", "0", "0", "0", "0", "0", "0", "0", "0", \(a\_N\)}
              }], ")"}]}], TraditionalForm]]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[StyleBox[
"The elements of the above matrix can be written in a unified way with the \
following extension of the definition of the elements:"]], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(a\_n := 0, \)\)]],
  "   if    ",
  Cell[BoxData[
      \(TraditionalForm\`n < 0\)]],
  "  ",
  " or   ",
  Cell[BoxData[
      \(TraditionalForm\`n > N\)]],
  "."
}], "DisplayFormula",
  FontWeight->"Plain"],

Cell["Now we have", "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox["RH",
            FontSlant->"Italic"], "(", "p", ")"}], "=", 
        \(\([a\_\(2  i - j\)]\)\_\(i = 1, 2, \[CenterEllipsis], N\nj = 1, 2, 
            \[CenterEllipsis], N\)\)}], TraditionalForm]]]], "DisplayFormula",\

  FontSlant->"Italic"],

Cell[TextData[StyleBox[
"Using the above notations the Routh\[Dash]Hurwitz criterion (see [3, p. \
559]) can be formulated as follows."]], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Theorem 3", "Subsubsection"],

Cell[TextData[{
  "Let us suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0 > 0. \)]],
  " Then the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " in ",
  StyleBox["(1) ",
    FontSlant->"Plain"],
  "is stable if and only if the chief minors of RH",
  StyleBox["(",
    FontSlant->"Plain"],
  "p",
  StyleBox[") ",
    FontSlant->"Plain"],
  "are all positive, i.e. "
}], "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[CapitalDelta]\_n\), ":=", 
        RowBox[{
          RowBox[{"det", "(", GridBox[{
                {\(a\_1\), \(a\_0\), "\[CenterEllipsis]", \(a\_\(2 - n\)\)},
                {\(a\_3\), \(a\_2\), "\[CenterEllipsis]", \(a\_\(4 - n\)\)},
                {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                  "\[DescendingEllipsis]", "\[VerticalEllipsis]"},
                {\(a\_\(2  n - 1\)\), \(a\_\(2  n - 2\)\), 
                  "\[CenterEllipsis]", \(a\_n\)}
                }], ")"}], ">", 
          \(0\ \ \ \ \ \(\((n = 1, 2, \[CenterEllipsis], N)\) . \)\)}]}], 
      TraditionalForm]]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[
  "We shall give a function which tests the above criterion (without he \
assumption on positivity of "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`a\_0\)]]],
  StyleBox[")."]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[StyleBox[
"First we define a function which gives the Routh\[Dash]Hurwitz matrix \
(3)."]], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(\(RH[polyvalue_, variable_] := \n
      Module[{lc = \nReverse[\nCoefficientList[polyvalue, variable]], \n
          deg = Exponent[polyvalue, variable], a}, \na[k_ /; k < 0] := 0; \n
        a[k_ /; 0 \[LessEqual] k \[LessEqual] deg] := 
          lc[\([k + 1]\)]\/Sign[First[lc]]; \na[k_ /; k > deg] := 0; \n
        Table[a[2  i - j], {i, deg}, {j, deg}]]\t\t\)\)], "Input",
  CellLabel->"In[26]:="],

Cell[TextData[StyleBox[
"The Routh\[Dash]Hurwitz matrix of the polynomials"]], "Text",
  FontWeight->"Plain"],

Cell[BoxData[{
    \(p\_10[z_] := z\^3 + a\ z\^2 + b\ z + 1\), 
    \(p\_11[z_] := z\^4 + a\ z\^3 + b\ z\^2 + c\ z + 1\)}], "Input",
  CellLabel->"In[27]:="],

Cell[TextData[StyleBox["are as follows"]], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[RH[p\_10[z], z]]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"a", "1", "0"},
          {"1", "b", "a"},
          {"0", "0", "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[29]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TableForm[RH[p\_11[z], z]]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    TagBox[GridBox[{
          {"a", "1", "0", "0"},
          {"c", "b", "a", "1"},
          {"0", "1", "c", "b"},
          {"0", "0", "0", "1"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output",
  CellLabel->"Out[30]//TableForm="]
}, Open  ]],

Cell[TextData[StyleBox[
"The chief minors can be obtained in the following way."]], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(\[CapitalDelta][polyvalue_, variable_, n_] := \n
      Det[\(RH[polyvalue, variable]\)[\([Range[n], Range[n]]\)]]\)], "Input",
  CellLabel->"In[31]:="],

Cell[TextData[StyleBox[
"Let us apply this function to the previous examples."]], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(\[CapitalDelta][p\_10[z], z, #]&\), " ", "/@", 
      StyleBox[" ",
        FontColor->RGBColor[1, 0, 0]], \(Range[3]\)}]], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({a, \(-1\) + a\ b, \(-1\) + a\ b}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(\[CapitalDelta][p\_11[z], z, #]&\), 
      StyleBox[" ",
        FontColor->GrayLevel[0]], "/@", " ", 
      RowBox[{
        StyleBox[
          RowBox[{
            StyleBox["Ra",
              FontColor->GrayLevel[0]], "nge"}]], "[", "4", "]"}]}]], "Input",\

  CellLabel->"In[33]:="],

Cell[BoxData[
    \({a, a\ b - c, \(-a\^2\) + a\ b\ c - c\^2, \(-a\^2\) + a\ b\ c - c\^2}
      \)], "Output",
  CellLabel->"Out[33]="]
}, Open  ]],

Cell[TextData[StyleBox[
"The following function tests the stability of the polynomial using the \
conditions of Theorem 3."]], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(RouthHurwitz[polyvalue_, variable_] := \n
      Module[\n{deg = Exponent[polyvalue, variable], tf}, \n
        tf = Array[Positive[\[CapitalDelta][polyvalue, variable, #]]&, deg, 
            1, And]; \nIf[tf, "\<Stable\>", "\<Unstable\>", tf]]\)], "Input",
  CellLabel->"In[34]:="],

Cell[TextData[StyleBox[
"If the coefficients are numerical values, then a well-defined answer will be \
obtained."]], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(RouthHurwitz[#[z], z]&\)\ /@
      \ {p\_1, p\_2, p\_4, p\_5, p\_6, p\_7, p\_8, p\_9}\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \({"Unstable", "Stable", "Stable", "Stable", "Unstable", "Unstable", 
      "Stable", "Unstable"}\)], "Output",
  CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[StyleBox[
"If there are symbolic numbers or parameters involved in the coefficients \
then the answer still contains relevant information."]], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    \(RouthHurwitz[p\_10[z], z]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(Positive[a] && Positive[\(-1\) + a\ b] && Positive[\(-1\) + a\ b]\)], 
  "Output",
  CellLabel->"Out[36]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RouthHurwitz[p\_11[z], z]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(Positive[a] && Positive[a\ b - c] && 
      Positive[\(-a\^2\) + a\ b\ c - c\^2] && 
      Positive[\(-a\^2\) + a\ b\ c - c\^2]\)], "Output",
  CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[StyleBox[
"In 1914 Li\[EAcute]nard and Chippart discovered that the amount of \
calculation can significantly be reduced, namely, it is enough to calculate \
every second determinant. More precisely, the following statement (see e.g. \
[4, p. 96]) is true."]], "Text",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theorem 4", "Subsubsection"],

Cell[TextData[{
  "Let us suppose that ",
  Cell[BoxData[
      \(TraditionalForm\`a\_0 > 0. \)]],
  " Then the polynomial ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " in ",
  StyleBox["(1) ",
    FontSlant->"Plain"],
  "is stable if and only if every coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and the chief minors "
}], "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[CapitalDelta]\_\(N - 1\), 
    \[CapitalDelta]\_\(N - 3\), \[CapitalDelta]\_\(N - 5\), 
    \[CenterEllipsis]\)]]], "DisplayFormula",
  FontWeight->"Plain"],

Cell["are all positive.", "Text",
  FontSlant->"Italic"],

Cell[TextData[{
  StyleBox[
  "The following function to test the Li\[EAcute]nard\[Dash]Chippart \
criterion is based upon the functions "],
  StyleBox["Stodola[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["and "],
  StyleBox["\[CapitalDelta][]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["introduced above."]
}], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{
      StyleBox[\(LienardChippart[polyvalue_, variable_]\),
        FontSlant->"Plain"], 
      StyleBox[":=",
        FontSlant->"Plain"], "\n", 
      RowBox[{
        StyleBox["Module",
          FontSlant->"Plain"], 
        StyleBox["[",
          FontSlant->"Plain"], "\n", 
        RowBox[{
          StyleBox[\({deg = Exponent[polyvalue, variable], tf}\),
            FontSlant->"Plain"], 
          StyleBox[",",
            FontSlant->"Plain"], "\n", 
          RowBox[{
            RowBox[{
              StyleBox["tf",
                FontSlant->"Plain"], 
              StyleBox["=",
                FontSlant->"Plain"], 
              RowBox[{
                StyleBox[\(Stodola[polyvalue, variable]\),
                  FontSlant->"Plain"], 
                StyleBox["&&",
                  FontSlant->"Plain"], 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["And",
                      FontSlant->"Plain"], 
                    StyleBox["@@",
                      FontSlant->"Plain"], 
                    StyleBox["\n",
                      FontSlant->"Plain"], 
                    StyleBox["\t\t\t\t",
                      FontSlant->"Plain"], 
                    RowBox[{
                      StyleBox["Positive",
                        FontSlant->"Plain"], 
                      StyleBox["[",
                        FontSlant->"Plain"], 
                      RowBox[{
                        
                        StyleBox[\(\[CapitalDelta][polyvalue, variable, #]&\),
                          
                          FontSlant->"Plain"], 
                        StyleBox["/@",
                          FontSlant->"Plain"], 
                        StyleBox["\n",
                          FontSlant->"Plain"], 
                        StyleBox["\t\t\t\t",
                          FontSlant->"Plain"], 
                        RowBox[{
                          StyleBox["Range",
                            FontSlant->"Plain"], 
                          StyleBox["[",
                            FontSlant->"Plain"], 
                          StyleBox[\(deg - 1, 1, \(-2\)\),
                            FontSlant->"Plain"], 
                          StyleBox["]",
                            FontSlant->"Plain",
                            FontColor->GrayLevel[0]]}]}], 
                      StyleBox["]",
                        FontSlant->"Plain"]}]}], 
                  StyleBox[")",
                    FontSlant->"Plain"]}]}]}], 
            StyleBox[";",
              FontSlant->"Plain"], "\n", 
            StyleBox[\(If[tf, "\<Stable\>", "\<Unstable\>", tf]\),
              FontSlant->"Plain"]}]}], 
        StyleBox["]",
          FontSlant->"Plain"]}]}]], "Input",
  CellLabel->"In[38]:=",
  FontSlant->"Italic"],

Cell[TextData[StyleBox["Let us see some examples."]], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(LienardChippart[#[z], z]&\), " ", "/@", 
      StyleBox[" ",
        FontColor->GrayLevel[0]], 
      \({p\_1, p\_2, p\_4, p\_5, p\_6, p\_7, p\_8, p\_9}\)}]], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({"Unstable", "Stable", "Stable", "Stable", "Unstable", "Unstable", 
      "Stable", "Unstable"}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LienardChippart[p\_10[z], z]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(Sign[b] == Sign[a] == 1 && Positive[\(-1\) + a\ b]\)], "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(LienardChippart[p\_11[z], z]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(Sign[c] == Sign[b] == Sign[a] == 1 && 
      Positive[\(-a\^2\) + a\ b\ c - c\^2] && Positive[a]\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6 EUCLIDEAN CRITERION", "Section"],

Cell[TextData[StyleBox[
"We obtain a necessary and sufficient condition for the stability problem \
using the principle of arguments and the theory of Cauchy indices of rational \
functions."]], "Text",
  FontWeight->"Plain"],

Cell["\<\
To the formulation of the final result let us consider polynomial (1) and \
introduce two polynomials in the following way.\
\>", "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(f\_0\)(z)\), ":=", 
          RowBox[{
          \(\(a\_0\) z\^N\), "-", \(\(a\_2\) z\^\(N - 2\)\), "+", " ", 
            RowBox[{"\[CenterEllipsis]", 
              StyleBox["      ",
                FontColor->RGBColor[1, 0, 0]], 
              \((z \[Element] \[DoubleStruckCapitalC])\)}]}]}], ",", 
        StyleBox[
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], " "}]],
          FontColor->RGBColor[1, 0, 0]], 
        StyleBox[
          RowBox[{
            StyleBox[" ",
              FontColor->RGBColor[1, 0, 0]], 
            StyleBox["    ",
              FontColor->GrayLevel[0]]}]], 
        RowBox[{
          StyleBox[\(\(f\_1\)(z)\),
            FontColor->GrayLevel[0]], 
          StyleBox[":=",
            FontColor->GrayLevel[0]], 
          RowBox[{
            StyleBox[\(\(a\_1\) z\^\(N - 1\)\),
              FontColor->GrayLevel[0]], 
            StyleBox["-",
              FontColor->GrayLevel[0]], 
            StyleBox[\(\(a\_3\) z\^\(N - 3\)\),
              FontColor->GrayLevel[0]], 
            StyleBox["+",
              FontColor->GrayLevel[0]], 
            StyleBox[" ",
              FontColor->GrayLevel[0]], 
            RowBox[{
              RowBox[{
                StyleBox["\[CenterEllipsis]",
                  FontColor->GrayLevel[0]], 
                StyleBox[
                  RowBox[{
                    StyleBox["    ",
                      FontColor->GrayLevel[0]], " "}]], "(", 
                \(z \[Element] \[DoubleStruckCapitalC]\), ")"}], "."}]}]}]}], 
      TraditionalForm]]]], "DisplayFormula",
  FontWeight->"Plain"],

Cell[TextData[{
  "From the long division (Euclidean) algorithm it follows that for the given \
polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`f\_0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  " there exist a uniquely determined number ",
  Cell[BoxData[
      \(TraditionalForm\`m \[Element] \[DoubleStruckCapitalN]\)]],
  " and nonzero polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`f\_2, f\_3, \[CenterEllipsis], f\_m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\_2, q\_3, \[CenterEllipsis], q\_m\)]],
  " for which the following relations hold:  "
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[{
    FormBox[
    \(\(f\_0\)(z) = \(\(q\_1\)(z)\) \(\(f\_1\)(z)\) - \(f\_2\)(z), \n
      \(f\_1\)(z) = \(\(q\_2\)(z)\) \(\(f\_2\)(z)\) - \(f\_3\)(z), \n
      \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\), 
      TraditionalForm], 
    FormBox[
      RowBox[{
        FormBox[
          \(\(f\_\(k - 1\)\)(z) = 
            \(\(q\_k\)(z)\) \(\(f\_k\)(z)\) - \(f\_\(k + 1\)\)(z), \n
          \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[VerticalEllipsis]\),
          "TraditionalForm"], " "}], TraditionalForm], 
    FormBox[
    \(\(f\_\(m - 1\)\)(z) = \(\(q\_m\)(z)\) \(\(f\_m\)(z)\), \), 
      TraditionalForm]}]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["where the degree of "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`f\_k\)]]],
  StyleBox[" is less than the degree of "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm
      \`\(f\_\(k - 1\)\ \ \(\((k = 2, 3, \[CenterEllipsis], m)\) . \)\ 
      \)\)]]],
  StyleBox[" The polynomial "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\((\(-f\_\(k + 1\)\))\)\)]]],
  StyleBox[" \[LongDash]resp. "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`q\_k\)]]],
  StyleBox["\[LongDash] is called the "],
  StyleBox["remainder",
    FontSlant->"Italic"],
  StyleBox["\[LongDash]resp. "],
  StyleBox["quotient",
    FontSlant->"Italic"],
  StyleBox["\[LongDash]in the "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`k\)]]],
  StyleBox["-th step "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(\ \ \((k = 1, 2, \[CenterEllipsis], m)\)\)\)]]],
  StyleBox[" of the division algorithm (5)."]
}], "Text",
  FontWeight->"Plain"],

Cell["The following statement is true (see [2, Theorem 6.7b]).", "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Theorem 5", "Subsubsection"],

Cell[TextData[{
  "The polynomial ",
  StyleBox["(1) ",
    FontSlant->"Plain"],
  "is stable if and only if ",
  Cell[BoxData[
      \(TraditionalForm\`m = N\)]],
  " in ",
  StyleBox["(5) ",
    FontSlant->"Plain"],
  " and the quotient polynomials ",
  Cell[BoxData[
      \(TraditionalForm\`q\_k\)]],
  "   ",
  StyleBox["(",
    FontSlant->"Plain"],
  "k=1,2,\[CenterEllipsis],m",
  StyleBox[") ",
    FontSlant->"Plain"],
  "are in the following form:"
}], "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(q\_k\)(z) = 
      \(\[Gamma]\_k\) z\ \ \ \ \ 
        \((z \[Element] \[DoubleStruckCapitalC]; \ k = 1, 2, 
          \[CenterEllipsis], m)\)\)]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell["where", "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Gamma]\_k\), ">", 
        RowBox[{"0", "     ", 
          RowBox[{
            StyleBox["(",
              FontSlant->"Italic"], " ", \(k = 1, 2, \[CenterEllipsis], m\), 
            ")"}]}]}], TraditionalForm]]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["This criterion can be implemented in "],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  StyleBox[" as follows."]
}], "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    RowBox[{\(Euclidean[polyvalue_, variable_]\), ":=", "\n", 
      RowBox[{"Module", "[", 
        RowBox[{
        \({deg = Exponent[polyvalue, variable], op, f, tf}\), ",", "\n", 
          RowBox[{
          \(op[{q_, d_, r_, v_}] := 
              \n{PolynomialQuotient[d, r, v], r, \n
                \(-PolynomialRemainder[d, r, v]\), v}\), ";", "\n", 
            \(f[k_] := 
              \[Sum]\+\(i = 0\)\%\(Quotient[deg - k, 2]\)\(\((\(-1\))\)\^i\) 
                  polyvalue[\([\(-2\) i - 1 - k]\)]\), ";", "\n", 
            \(tf = And@@
                \((\(\((Length[#] == 2 && First[#] == 0 && Last[#] > 0)\)&\)/@
                    Together[
                      Simplify[
                        CoefficientList[
                          First[Transpose[
                              FixedPointList[
                                op, {variable, f[0], f[1], variable}, 
                                SameTest \[Rule] \((#2[\([3]\)] == 0&)\)]]], 
                          variable]]])\)\), ";", "\n", 
            RowBox[{"If", "[", 
              StyleBox[\(tf, "\<Stable\>", "\<Unstable\>", tf\),
                FontSlant->"Plain"], "]"}]}]}], "]"}]}]], "Input",
  CellLabel->"In[42]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Euclidean[#[z], z]&\)\ /@
      \ {p\_1, p\_2, p\_4, p\_5, p\_6, p\_7, p\_8, p\_9}\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \({"Unstable", "Stable", "Stable", "Stable", "Unstable", "Unstable", 
      "Stable", "Unstable"}\)], "Output",
  CellLabel->"Out[43]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Euclidean[p\_10[z], z]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(1\/a > 0 && a\^2\/\(\(-1\) + a\ b\) > 0 && \(\(-1\) + a\ b\)\/a > 0\)], 
  "Output",
  CellLabel->"Out[44]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Euclidean[p\_11[z], z]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(1\/a > 0 && a\^2\/\(a\ b - c\) > 0 && 
      \(-\(\((a\ b - c)\)\^2\/\(a\ \((a\^2 - a\ b\ c + c\^2)\)\)\)\) > 0 && 
      \(a\^2 - a\ b\ c + c\^2\)\/\(\(-a\)\ b + c\) > 0\)], "Output",
  CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[{
  "We propose the reader to proceed with loading either the package ",
  StyleBox["Algebra`InequalitySolve`",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "or the package ",
  StyleBox["Algebra`AlgebraicInequalities` ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["and using them.",
    FontFamily->"Times New Roman"]
}], "Text",
  FormatType->TextForm,
  FontWeight->"Plain"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["7 CONTINUED FRACTION CRITERION", "Section"],

Cell["\<\
Another necessary and sufficient condition for the stability problem may be \
given by means of continued fractions.\
\>", "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[
  "It is known that some real functions can be written in the following "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`m\)]]],
  StyleBox["-"],
  StyleBox["terminate continued fraction form:",
    FontSlant->"Italic"]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    FormBox[
      StyleBox[
        \(b\_1\/\(1 + 
              \(\(b\_2\) z\)\/\(1 + 
                  \(\(b\_3\) z\)\/\(\ \ \ \ \ \ \ 
                    \[VerticalEllipsis]\ \ \n\t1 + \(b\_m\) z\)\)\)\),
        FontSize->16], TraditionalForm]],
  FontSize->14]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["where "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`b\_k\ \((k = 1, 2, , \[CenterEllipsis], m)\)\)]]],
  StyleBox[
  " are appropriate real numbers. It is obvious that there exist rational \
functions for which such a representation does not exist. Consider for \
example those which have the zero value at the point "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`z = 0\)]]],
  StyleBox["."]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[StyleBox["Now suppose that the rational function"]], "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`r(z) := 
      \(c\_0 + \(c\_1\) z + \[CenterEllipsis] + \(c\_s\) z\^s\)\/\(d\_0 + 
          \(d\_1\) z + \[CenterEllipsis] + \(d\_t\) z\^t\)\)]]], 
  "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox[
  "has a representation of the form (8). Extend the definition of the \
coefficients "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`c\_k\)]]],
  StyleBox[" and "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`d\_k\)]]],
  StyleBox[" in (9) in the following way:"]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(c\_n := 0, \)\)]],
  "   if ",
  Cell[BoxData[
      \(TraditionalForm\`n > s\)]],
  "        and        ",
  Cell[BoxData[
      \(TraditionalForm\`\(d\_n := 0, \)\)]],
  "    if ",
  Cell[BoxData[
      \(TraditionalForm\`n > \(t . \)\)]],
  " "
}], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["It may be proved ([3, p. 547]) that in this case the numbers "],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`b\_k\)]]],
  StyleBox[" in (8) satisfy the following recurrence relations:"]
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(c\_n\^\((\(-1\))\) := d\_n\), " ", ",", 
          StyleBox[
            RowBox[{
              StyleBox["   ",
                FontColor->RGBColor[1, 0, 0]], "   "}]], 
          \(c\_n\^\((0)\) := 
            c\_n\ \ \ \ \ \((n = 0, 1, 2, \[CenterEllipsis])\)\), ",", "\n", 
          "\n", \(b\_\(k + 1\) := 
            c\_0\^\((k)\)\/c\_0\^\((k - 1)\)\ \ \ \ \ 
              \((k = 0, 1, 2, \[CenterEllipsis])\)\), ",", "\n", "\n", 
          \(c\_n\^\((k + 1)\) := 
            \(b\_\(k + 1\)\) c\_\(n + 1\)\^\((k - 1)\) - 
              c\_\(n + 1\)\^\((k)\)\ \ \ \ \ \ 
                \(\((k = 0, 1, 2, \[CenterEllipsis]; n = 0, 1, 2, 
                    \[CenterEllipsis])\) . \)\)}], "\n", "\t\t\t\t"}], 
      TraditionalForm]]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  "The computation of ",
  Cell[BoxData[
      \(TraditionalForm\`\(b\_\(k + 1\)\ \)\)]],
  " (which in this manner is a variant of the original ",
  StyleBox["Routh algorithm",
    FontSlant->"Italic"],
  ") starts from the first two rows of ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\^\((\(-1\))\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\^\((0)\)\)]],
  " (the coefficients of the denominator and that of the numerator) and then \
proceeds as indicated in the following table:"
}], "Text",
  FontWeight->"Plain"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .375 
%%ImageSize: 440 180 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.00208333 0.0416667 0.00166667 [
[ 0 0 0 0 ]
[ 1 .375 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .375 L
0 .375 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.01 0 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.01 0 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
.999 g
0 .04167 m
.91667 .04167 L
.91667 .34167 L
0 .34167 L
0 .04167 L
F
0 g
gsave
.25 .34167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .27708 .33667 -1 -0.7 Mshowa
P
gsave
.27083 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(-1)] .2875 .36167 -1 -0.7 Mshowa
P
gsave
.3125 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.41667 .34167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .44375 .33667 -1 -0.7 Mshowa
P
gsave
.4375 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(-1)] .45417 .36167 -1 -0.7 Mshowa
P
gsave
.47917 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58333 .34167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .61042 .33667 -1 -0.7 Mshowa
P
gsave
.60417 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(-1)] .62083 .36167 -1 -0.7 Mshowa
P
gsave
.64583 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.75 .34167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(3)] .77708 .33667 -1 -0.7 Mshowa
P
gsave
.77083 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(-1)] .7875 .36167 -1 -0.7 Mshowa
P
gsave
.8125 .36167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.25 .24167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .27708 .23667 -1 -0.7 Mshowa
P
gsave
.27083 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .29167 .26167 -1 -0.7 Mshowa
P
gsave
.30417 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.25 .14167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .27708 .13667 -1 -0.7 Mshowa
P
gsave
.27083 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .29167 .16167 -1 -0.7 Mshowa
P
gsave
.30417 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.25 .04167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .27708 .03667 -1 -0.7 Mshowa
P
gsave
.27083 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .29167 .06167 -1 -0.7 Mshowa
P
gsave
.30417 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.41667 .24167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .44375 .23667 -1 -0.7 Mshowa
P
gsave
.4375 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .45833 .26167 -1 -0.7 Mshowa
P
gsave
.47083 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.41667 .14167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .44375 .13667 -1 -0.7 Mshowa
P
gsave
.4375 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .45833 .16167 -1 -0.7 Mshowa
P
gsave
.47083 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.41667 .04167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .44375 .03667 -1 -0.7 Mshowa
P
gsave
.4375 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .45833 .06167 -1 -0.7 Mshowa
P
gsave
.47083 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58333 .24167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .61042 .23667 -1 -0.7 Mshowa
P
gsave
.60417 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .625 .26167 -1 -0.7 Mshowa
P
gsave
.6375 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58333 .14167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .61042 .13667 -1 -0.7 Mshowa
P
gsave
.60417 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .625 .16167 -1 -0.7 Mshowa
P
gsave
.6375 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.58333 .04167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .61042 .03667 -1 -0.7 Mshowa
P
gsave
.60417 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .625 .06167 -1 -0.7 Mshowa
P
gsave
.6375 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.75 .24167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(3)] .77708 .23667 -1 -0.7 Mshowa
P
gsave
.77083 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .79167 .26167 -1 -0.7 Mshowa
P
gsave
.80417 .26167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.75 .14167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(3)] .77708 .13667 -1 -0.7 Mshowa
P
gsave
.77083 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .79167 .16167 -1 -0.7 Mshowa
P
gsave
.80417 .16167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.75 .04167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(c) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(3)] .77708 .03667 -1 -0.7 Mshowa
P
gsave
.77083 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(H) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .79167 .06167 -1 -0.7 Mshowa
P
gsave
.80417 .06167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
63.000000 14.437500 moveto
(L) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: font Math2Mono
%%+ font Courier
grestore
gsave
.91667 .34167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
(...) show
63.000000 14.437500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
gsave
.91667 .24167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
(...) show
63.000000 14.437500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
gsave
.91667 .14167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
(...) show
63.000000 14.437500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
gsave
.91667 .04167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
(...) show
63.000000 14.437500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
gsave
0 .29167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(0)] .02708 .28667 -1 -0.7 Mshowa
P
gsave
0 .19167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(1)] .02708 .18667 -1 -0.7 Mshowa
P
gsave
0 .09167 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(b) show
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
p
/Courier findfont 9 scalefont setfont
[(2)] .02708 .08667 -1 -0.7 Mshowa
P
.1 Mabswid
.41667 .34167 m
.29167 .19167 L
s
% Start of user PostScript
200. 180. 140. 90. MAarrowhead1
% End of user PostScript
.41667 .24167 m
.30208 .19167 L
s
% Start of user PostScript
200. 120. 145. 90. MAarrowhead1
% End of user PostScript
.41667 .24167 m
.29167 .09167 L
s
% Start of user PostScript
200. 120. 140. 30. MAarrowhead1
% End of user PostScript
.41667 .14167 m
.30208 .09167 L
s
% Start of user PostScript
200. 60. 145. 30. MAarrowhead1
% End of user PostScript
.58333 .34167 m
.45833 .19167 L
s
% Start of user PostScript
280. 180. 220. 90. MAarrowhead1
% End of user PostScript
.58333 .24167 m
.46875 .19167 L
s
% Start of user PostScript
280. 120. 225. 90. MAarrowhead1
% End of user PostScript
.58333 .24167 m
.45833 .09167 L
s
% Start of user PostScript
280. 120. 220. 30. MAarrowhead1
% End of user PostScript
.58333 .14167 m
.46875 .09167 L
s
% Start of user PostScript
280. 60. 225. 30. MAarrowhead1
% End of user PostScript
.75 .34167 m
.625 .19167 L
s
% Start of user PostScript
360. 180. 300. 90. MAarrowhead1
% End of user PostScript
.75 .24167 m
.63542 .19167 L
s
% Start of user PostScript
360. 120. 305. 90. MAarrowhead1
% End of user PostScript
.75 .24167 m
.625 .09167 L
s
% Start of user PostScript
360. 120. 300. 30. MAarrowhead1
% End of user PostScript
.75 .14167 m
.63542 .09167 L
s
% Start of user PostScript
360. 60. 305. 30. MAarrowhead1
% End of user PostScript
.23958 .35 m
.04167 .30833 L
s
% Start of user PostScript
115. 185. 20. 160. MAarrowhead1
% End of user PostScript
.23958 .25833 m
.04167 .29167 L
s
% Start of user PostScript
115. 130. 20. 150. MAarrowhead1
% End of user PostScript
.23958 .25 m
.04167 .20833 L
s
% Start of user PostScript
115. 125. 20. 100. MAarrowhead1
% End of user PostScript
.23958 .15833 m
.04167 .19167 L
s
% Start of user PostScript
115. 70. 20. 90. MAarrowhead1
% End of user PostScript
.23958 .15 m
.04167 .10833 L
s
% Start of user PostScript
115. 65. 20. 40. MAarrowhead1
% End of user PostScript
.23958 .05833 m
.04167 .09167 L
s
% Start of user PostScript
115. 10. 20. 30. MAarrowhead1
% End of user PostScript
gsave
.46667 .00833 -61 -6.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 23 translate 1 -1 scale
63.000000 14.437500 moveto
%%IncludeResource: font Courier-Plain-Italic
%%IncludeFont: Courier-Plain-Italic
/Courier-Plain-Italic findfont 12.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 14.437500 moveto
(...) show
63.000000 14.437500 moveto
0.000000 0.000000 rmoveto
1.000000 setlinewidth
%%DocumentNeededResources: font Courier-Plain-Italic
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier-Plain-Italic
%%DocumentSuppliedFonts:
%%DocumentFonts: font Courier-Plain-Italic
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[61]:=",
  ImageSize->{440, 180},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006h0000]1000`40O003h00Oogoo^Goo003oOoni
Ool00?mookUoo`00ogoo^Goo003oOoniOol00?mookUoo`00ogoo^Goo003oOoniOol00?mookUoo`00
ogoo^Goo003oOoniOol00?mookUoo`00ogoo^Goo003oOoniOol00?mookUoo`00d7oo0P001Goo0P00
1Goo0P00f7oo003@Ool20005Ool20005Ool2003HOol00?mookUoo`00ogoo^Goo003oOoniOol00?mo
okUoo`00ogoo^Goo003oOoniOol00?mookUoo`00ogoo^Goo003oOoniOol007]oo`03001oogoo04Ao
o`D004Eoo`<004Moo`80061oo`00NWoo00<007oo0000Agoo00<007ooOol0AGoo00<007ooOol0BGoo
00<007ooOol0GGoo001jOol00`00Ool00017Ool00`00Oomoo`16Ool00`00Oomoo`17Ool00`00Oomo
o`1NOol0075oo`@000Eoo`03001oo`0003eoo`@000Ioo`03001oogoo03eoo`@000Eoo`03001oogoo
03eoo`@000Moo`03001oogoo03]oo`8000Eoo`8000Eoo`80019oo`00L7oo00<007ooOol00Woo00<0
07ooOol00Woo00<007oo0000?7oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0?7oo00<0
07ooOol00Woo00L007ooOomoo`00Ool0000mOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool0
000mOol20005Ool20005Ool2000BOol0071oo`03001oogoo00Qoo`03001oogoo03]oo`03001oogoo
00Moo`8003ioo`03001oogoo00Moo`03001oogoo03aoo`03001oogoo00Qoo`03001oogoo05ioo`00
L7oo00<007ooOol0AWoo00<007ooOol0Agoo00<007ooOol0AWoo00<007ooOol0JGoo001WOol30007
Ool01@00Oomoogoo0000A7oo00D007ooOomoo`0004Eoo`05001oogooOol00014Ool01@00Oomoogoo
0000IWoo001QOol6000;Ool40015Ool40016Ool40015Ool4001VOol005]oo`H00?mooeQoo`00EGoo
1P0087oo00<007ooOol02Woo00<007ooOol0>Woo00<007ooOol02Goo00<007ooOol0>Woo00<007oo
Ool02Goo00<007ooOol0>Woo00<007ooOol02Woo00<007ooOol0DGoo001?Ool6000UOol00`00Oomo
o`04Ool30005Ool00`00Oomoo`0hOol00`00Oomoo`03Ool30005Ool00`00Oomoo`0hOol00`00Oomo
o`03Ool30005Ool00`00Oomoo`0hOol00`00Oomoo`03Ool30006Ool00`00Oomoo`1@Ool004Yoo`D0
02Yoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo03Ioo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo03Ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo03Ioo`03001oogoo
00Aoo`03001oogoo00Moo`03001oogoo04moo`00A7oo1P00;goo00<007ooOol01Woo00<007ooOol0
1Goo00<007ooOol0=Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol0=Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
Cgoo000nOol6000eOol00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`05
Ool00`00Oomoo`05Ool00`00Oomoo`0fOol00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`0f
Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`1?Ool003Qoo`H003]oo`03001oogoo00Eo
o`03001oo`0000Ioo`03001oogoo03Ioo`03001oogoo00Aoo`03001oo`0000Ioo`03001oogoo03Io
o`03001oogoo00Aoo`03001oo`0000Ioo`03001oogoo03Ioo`03001oogoo00Aoo`03001oo`0000Mo
o`03001oogoo04moo`00<Woo1P00@Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0>7oo
00<007ooOol017oo00<007ooOol017oo00<007ooOol0>7oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol0>7oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0D7oo000]Ool50019Ool0
0`00Oomoo`0:Ool00`00Oomoo`0jOol00`00Oomoo`09Ool00`00Oomoo`0jOol00`00Oomoo`09Ool0
0`00Oomoo`0jOol00`00Oomoo`0:Ool00`00Oomoo`1AOol001Yoo`03001oogoo00Yoo`H00?moohao
o`0067oo0P001goo1P00ogooTWoo000FOol30002Ool6003oOonHOol001Aoo`L00?mooiioo`0037oo
0`000goo2000IWoo00@007ooOomoo`D0041oo`04001oogooOol50010Ool01000Oomoogoo1@00WGoo
000<Ool00`00Oomoo`08Ool5001TOol30002Ool9000lOol20002Ool9000lOol20002Ool9002HOol0
00eoo`03001oogoo075oo`<000=oo`@003moo`<000=oo`@003moo`<000=oo`@009]oo`000Woo1@00
1Woo00<007ooOol0LGoo10000goo1000?goo0`000goo1@00?Woo0`000goo1@00VGoo0003Ool01@00
Oomoogoo000017oo00<007oo0000Lgoo1@000Woo0P0000Aoo`00000003aoo`D0009oo`80009oo`80
03aoo`D000=oo`800003Ool0000009Moo`000goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool0LWoo00@007oo001oo`8000=oo`04001oogooOol2000kOol200000goo00000003Ool01000Oomo
ogoo0P00>goo0P0000=oo`00000017oo00<007ooOol00P00UGoo0004Ool01@00Oomoogoo0000NGoo
0P0000=oo`00Ool02Woo0P00>Goo00<007oo00002goo0`00>7oo0`002goo0`00TWoo0004Ool20002
Ool00`00Oomoo`07Ool:001WOol01000Oomoo`0037oo0`00=goo00<007oo00003Goo0P00=goo00<0
07oo00003Goo0P00T7oo0004Ool01000Ool000002goo1P00JWoo00D007ooOomoo`0000ioo`8003Eo
o`04001oogoo000>Ool2000eOol01000Oomoo`003Woo0P00SWoo0004Ool00`00Oomoo`0>Ool30000
0goo00000003001YOol00`00Oomoo`0>Ool2000gOol00`00Oomoo`0=Ool3000fOol00`00Oomoo`0=
Ool3002;Ool000=oo`80019oo`<000Aoo`D006Eoo`03001oogoo00moo`8003Eoo`03001oogoo011o
o`8003Aoo`03001oogoo011oo`8008Uoo`006Goo0P0027oo1000HWoo00<007ooOol047oo0`00<goo
00<007ooOol04Goo0P00<goo00<007ooOol04Goo0P00Qgoo000WOol5001NOol00`00Oomoo`0BOol2
000bOol00`00Oomoo`0BOol2000bOol00`00Oomoo`0BOol20025Ool002aoo`@005]oo`03001oogoo
01=oo`80035oo`03001oogoo01=oo`<0031oo`03001oogoo01=oo`<0089oo`00<7oo1@00EWoo00<0
07ooOol05Goo0P00<7oo00<007ooOol05Goo0P00;goo00<007ooOol05Goo0P00P7oo000eOol4001C
Ool00`00Oomoo`0FOol3000^Ool00`00Oomoo`0FOol2000^Ool00`00Oomoo`0FOol2001nOol003Uo
o`D004moo`03001oogoo01Qoo`8002aoo`03001oogoo01Qoo`<002]oo`03001oogoo01Qoo`<007]o
o`00?Woo1@00Bgoo00<007ooOol06Goo0P00:goo00<007ooOol06Woo0P00:Woo00<007ooOol06Woo
0P00NGoo0013Ool40018Ool00`00Oomoo`0JOol3000YOol00`00Oomoo`0KOol2000YOol00`00Oomo
o`0KOol2001gOol004Moo`D004Aoo`03001oogoo01aoo`8002Qoo`03001oogoo01aoo`<002Moo`03
001oogoo01aoo`<007Aoo`00C7oo1000@7oo00<007ooOol07Woo0P009goo00<007ooOol07Woo0P00
9Woo00<007ooOol07Woo0P00LWoo001@Ool5000lOol00`00Oomoo`0OOol2000VOol00`00Oomoo`0O
Ool2000UOol00`00Oomoo`0OOol2001`Ool005Eoo`@0029oo`03001oogoo01Aoo`03001oogoo021o
o`8000]oo`D001Aoo`03001oogoo025oo`8000]oo`<001Eoo`03001oogoo025oo`8000aoo`80061o
o`00FGoo1@0077oo00<007oo00005Woo00<007ooOol0;Woo00<007ooOol05Goo00<007ooOol0;Goo
00<007ooOol05Woo00<007ooOol0<7oo00<007ooOol0GGoo001NOol5000GOol00`00Ool0000GOol0
0`00Oomoo`0]Ool00`00Oomoo`0FOol00`00Oomoo`0]Ool00`00Oomoo`0FOol00`00Oomoo`0^Ool0
0`00Oomoo`1NOol006=oo`@000Yoo`@000Eoo`03001oo`0001Moo`03001oogoo02=oo`@000Ioo`03
001oogoo01Moo`03001oogoo02=oo`@000Eoo`03001oogoo01Moo`03001oogoo02=oo`@000Moo`03
001oogoo03]oo`8000Eoo`8000Eoo`80019oo`00Igoo0`001Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007oo000067oo00<007ooOol08Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
67oo00<007ooOol08Goo00<007ooOol00Woo00L007ooOomoo`00Ool0000IOol00`00Oomoo`0QOol0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool0000mOol20005Ool20005Ool2000BOol0071oo`03
001oogoo00Qoo`03001oogoo01Qoo`03001oogoo021oo`03001oogoo00Moo`8001]oo`03001oogoo
021oo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo021oo`03001oogoo00Qoo`03001oogoo
05ioo`00L7oo00<007ooOol097oo00<007ooOol07goo00<007ooOol097oo00<007ooOol087oo00<0
07ooOol08goo00<007ooOol087oo00<007ooOol0JGoo001WOol30007Ool01@00Oomoogoo00008Woo
00<007ooOol07goo00D007ooOomoo`00029oo`03001oogoo021oo`05001oogooOol0000QOol00`00
Oomoo`0POol01@00Oomoogoo0000IWoo001QOol6000;Ool4000SOol00`00Oomoo`0OOol4000SOol0
0`00Oomoo`0POol4000ROol00`00Oomoo`0POol4001VOol005]oo`H003Qoo`03001oogoo04Moo`03
001oogoo04Ioo`03001oogoo08Uoo`00EGoo1P0087oo00<007ooOol02Woo00<007ooOol03goo00<0
07ooOol0:7oo00<007ooOol02Goo00<007ooOol047oo00<007ooOol09goo00<007ooOol02Goo00<0
07ooOol047oo00<007ooOol09goo00<007ooOol02Woo00<007ooOol0DGoo001?Ool6000UOol00`00
Oomoo`03Ool50004Ool00`00Oomoo`0?Ool00`00Oomoo`0VOol00`00Oomoo`02Ool50004Ool00`00
Oomoo`0@Ool00`00Oomoo`0UOol00`00Oomoo`02Ool50004Ool00`00Oomoo`0@Ool00`00Oomoo`0U
Ool00`00Oomoo`02Ool50005Ool00`00Oomoo`1@Ool004Yoo`D002Yoo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00moo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo00moo`03001oogoo02Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00moo`03001o
ogoo02Aoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo04moo`00A7oo1P00;goo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol047oo00<007ooOol08goo00<007ooOol01Goo00<007oo
Ool01Goo00<007ooOol047oo00<007ooOol08goo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool047oo00<007ooOol08goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0Cgoo000nOol6
000eOol00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`0SOol00`00Oomo
o`05Ool00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`0ROol00`00Oomoo`05Ool00`00Oomo
o`05Ool00`00Oomoo`0AOol00`00Oomoo`0ROol00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`1?Ool003Qoo`H003]oo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo
029oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo025oo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo025oo`03001oogoo00Eoo`03001oogoo
00Ioo`03001oogoo04moo`00<Woo1P00@Woo00<007ooOol017oo0P001Woo00<007ooOol04goo00<0
07ooOol08Woo00<007ooOol00goo0P001Woo00<007ooOol057oo00<007ooOol08Goo00<007ooOol0
0goo0P001Woo00<007ooOol057oo00<007ooOol08Goo00<007ooOol00goo0P001goo00<007ooOol0
D7oo000]Ool50019Ool00`00Oomoo`0:Ool00`00Oomoo`0EOol00`00Oomoo`0ROol00`00Oomoo`09
Ool00`00Oomoo`0FOol00`00Oomoo`0QOol00`00Oomoo`09Ool00`00Oomoo`0FOol00`00Oomoo`0Q
Ool00`00Oomoo`0:Ool00`00Oomoo`1AOol001Yoo`03001oogoo00Yoo`H007Aoo`03001oogoo04Io
o`03001oogoo04Ioo`03001oogoo089oo`0067oo0P001goo1P00Ngoo00<007ooOol0AWoo00<007oo
Ool0AWoo00<007ooOol0PGoo000FOol30002Ool60021Ool00`00Oomoo`17Ool00`00Oomoo`16Ool0
0`00Oomoo`20Ool001Aoo`L008Qoo`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo07moo`00
2goo1@000Woo2000IWoo00@007ooOomoo`D001]oo`03001oogoo029oo`04001oogooOol5000LOol0
0`00Oomoo`0QOol01000Oomoogoo1@0077oo00<007ooOol0OWoo000=Ool00`00Oomoo`07Ool5001T
Ool30002Ool9000GOol00`00Oomoo`0ROol20002Ool9000HOol00`00Oomoo`0QOol20002Ool9000H
Ool00`00Oomoo`1mOol000eoo`03001oogoo075oo`<000=oo`@001]oo`03001oogoo025oo`<000=o
o`@001]oo`03001oogoo025oo`<000=oo`@001]oo`03001oogoo07eoo`000Woo1@001Woo00<007oo
Ool0LGoo10000goo10006Woo00<007ooOol08Woo0`000goo1@006Woo00<007ooOol08Goo0`000goo
1@006Woo00<007ooOol0O7oo0003Ool01@00Oomoogoo00001Goo00<007ooOol0LWoo1@000Woo0P00
00Aoo`00000001Qoo`03001oogoo025oo`D0009oo`80009oo`8001Uoo`03001oogoo021oo`D000=o
o`800003Ool0000001Uoo`03001oogoo07]oo`000goo00<007ooOol00Woo00@007ooOomoo`8007Ao
o`04001oo`00Ool20003Ool01000Oomoogoo0P005goo00<007ooOol08Goo0P0000=oo`0000000goo
00@007ooOomoo`8001Qoo`03001oogoo021oo`800003Ool0000000Aoo`03001oogoo008001Qoo`03
001oogoo07Yoo`0017oo00D007ooOomoo`0007Uoo`800003Ool007oo00Yoo`8001Ioo`03001oogoo
021oo`<000]oo`<001Ioo`03001oogoo01moo`<000]oo`<001Ioo`03001oogoo07Uoo`0017oo0P00
0Woo00<007ooOol01goo2P00Igoo00@007ooOol000aoo`<001Aoo`03001oogoo021oo`03001oo`00
00eoo`8001Eoo`03001oogoo01moo`03001oo`0000eoo`8001Eoo`03001oogoo07Qoo`0017oo00@0
07oo000000]oo`L006Uoo`05001oogooOol0000>Ool2000COol00`00Oomoo`0OOol01000Oomoo`00
3Woo0P004goo00<007ooOol07goo00@007ooOol000ioo`8001=oo`03001oogoo07Qoo`0017oo00<0
07ooOol03Woo0`000Woo1@00J7oo00<007ooOol03Woo0P004Goo00<007ooOol08goo00<007ooOol0
3Goo0`004Goo00<007ooOol08Woo00<007ooOol03Goo0`004Goo00<007ooOol0Mgoo0003Ool2000B
Ool30005Ool4001UOol00`00Oomoo`0?Ool2000@Ool00`00Oomoo`0ROol00`00Oomoo`0@Ool2000@
Ool00`00Oomoo`0QOol00`00Oomoo`0@Ool2000@Ool00`00Oomoo`1fOol001Uoo`8000Qoo`D0065o
o`03001oogoo011oo`<000ioo`03001oogoo029oo`03001oogoo015oo`8000moo`03001oogoo025o
o`03001oogoo015oo`8000moo`03001oogoo07Eoo`00:7oo1@00GGoo00<007ooOol04Woo0P003Goo
00<007ooOol08Woo00<007ooOol04Woo0P003Woo00<007ooOol08Goo00<007ooOol04Woo0P003Woo
00<007ooOol0M7oo000]Ool5001IOol00`00Oomoo`0COol2000<Ool00`00Oomoo`0ROol00`00Oomo
o`0COol3000<Ool00`00Oomoo`0QOol00`00Oomoo`0COol3000<Ool00`00Oomoo`1cOol0039oo`D0
05Aoo`03001oogoo01Eoo`8000Yoo`03001oogoo02=oo`03001oogoo01Eoo`8000Yoo`03001oogoo
029oo`03001oogoo01Eoo`8000Yoo`03001oogoo07=oo`00=goo1@00D7oo00<007ooOol05Woo0`00
27oo00<007ooOol08goo00<007ooOol05Woo0P002Goo00<007ooOol08Woo00<007ooOol05Woo0P00
2Goo00<007ooOol0LWoo000lOol4001=Ool00`00Oomoo`0HOol20007Ool00`00Oomoo`0ROol00`00
Oomoo`0HOol30007Ool00`00Oomoo`0QOol00`00Oomoo`0HOol30007Ool00`00Oomoo`1aOol0041o
o`D004Uoo`03001oogoo01Uoo`8000Ioo`03001oogoo029oo`03001oogoo01Yoo`8000Ioo`03001o
ogoo025oo`03001oogoo01Yoo`8000Ioo`03001oogoo071oo`00AGoo1@00AGoo00<007ooOol06Woo
0`0017oo00<007ooOol08Woo00<007ooOol06goo0P001Goo00<007ooOol08Goo00<007ooOol06goo
0P001Goo00<007ooOol0Kgoo001:Ool50011Ool00`00Oomoo`0LOol20003Ool00`00Oomoo`0ROol0
0`00Oomoo`0LOol30003Ool00`00Oomoo`0QOol00`00Oomoo`0LOol30003Ool00`00Oomoo`1^Ool0
04moo`D003aoo`03001oogoo01ioo`800003Ool007oo02Aoo`03001oogoo01ioo`800003Ool007oo
02=oo`03001oogoo01ioo`800003Ool007oo06moo`00E7oo1@00>7oo00<007ooOol07goo0`009Goo
00<007ooOol07goo0`0097oo00<007ooOol07goo0`00Kgoo001IOol4000NOol00`00Oomoo`0DOol0
0`00Oomoo`0POol2000;Ool5000DOol00`00Oomoo`0QOol2000;Ool3000EOol00`00Oomoo`0QOol2
000<Ool2001POol005eoo`D001Qoo`03001oo`0001Ioo`03001oogoo02ioo`03001oogoo01Eoo`03
001oogoo02eoo`03001oogoo01Ioo`03001oogoo031oo`03001oogoo05eoo`00HWoo1@004goo00<0
07oo00005goo00<007ooOol0;Goo00<007ooOol05Woo00<007ooOol0;Goo00<007ooOol05Woo00<0
07ooOol0;Woo00<007ooOol0GWoo001WOol30007Ool40005Ool00`00Ool0000GOol00`00Oomoo`0S
Ool40006Ool00`00Oomoo`0GOol00`00Oomoo`0SOol40005Ool00`00Oomoo`0GOol00`00Oomoo`0S
Ool40007Ool00`00Oomoo`0kOol20005Ool20005Ool2000BOol0071oo`03001oogoo009oo`03001o
ogoo009oo`03001oo`0001Qoo`03001oogoo025oo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo01Qoo`03001oogoo025oo`03001oogoo009oo`07001oogooOol007oo00006Goo00<007ooOol0
8Goo00<007ooOol00Woo00<007ooOol00Woo00<007oo0000?Goo0P001Goo0P001Goo0P004Woo001`
Ool00`00Oomoo`08Ool00`00Oomoo`0HOol00`00Oomoo`0POol00`00Oomoo`07Ool2000KOol00`00
Oomoo`0POol00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`0POol00`00Oomoo`08Ool00`00
Oomoo`1NOol0071oo`03001oogoo02Aoo`03001oogoo01moo`03001oogoo02Aoo`03001oogoo021o
o`03001oogoo02=oo`03001oogoo021oo`03001oogoo06Uoo`00Igoo0`001goo00D007ooOomoo`00
029oo`03001oogoo01moo`05001oogooOol0000ROol00`00Oomoo`0POol01@00Oomoogoo00008Goo
00<007ooOol087oo00D007ooOomoo`0006Ioo`00HGoo1P002goo10008goo00<007ooOol07goo1000
8goo00<007ooOol087oo10008Woo00<007ooOol087oo1000IWoo001KOol6000hOol00`00Oomoo`17
Ool00`00Oomoo`16Ool00`00Oomoo`29Ool005Eoo`H0021oo`03001oogoo00Yoo`03001oogoo00mo
o`03001oogoo02Qoo`03001oogoo00Uoo`03001oogoo011oo`03001oogoo02Moo`03001oogoo00Uo
o`03001oogoo011oo`03001oogoo02Moo`03001oogoo00Yoo`03001oogoo055oo`00Cgoo1P009Goo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol09Woo00<007ooOol017oo
00<007ooOol017oo00<007ooOol047oo00<007ooOol09Goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol047oo00<007ooOol09Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0D7oo
001:Ool5000ZOol00`00Oomoo`05Ool00`00Ool00006Ool00`00Oomoo`0?Ool00`00Oomoo`0TOol0
0`00Oomoo`04Ool00`00Ool00006Ool00`00Oomoo`0?Ool00`00Oomoo`0TOol00`00Oomoo`04Ool0
0`00Ool00006Ool00`00Oomoo`0?Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`00Ool00007Ool0
0`00Oomoo`1?Ool004Aoo`H002moo`03001oogoo00Eoo`03001oo`0000Ioo`03001oogoo011oo`03
001oogoo02=oo`03001oogoo00Aoo`03001oo`0000Ioo`03001oogoo011oo`03001oogoo02=oo`03
001oogoo00Aoo`03001oo`0000Ioo`03001oogoo011oo`03001oogoo02=oo`03001oogoo00Aoo`03
001oo`0000Moo`03001oogoo04moo`00?Woo1P00=Goo00<007ooOol01Goo00<007oo00001Woo00<0
07ooOol047oo00<007ooOol08goo00<007ooOol017oo00<007oo00001Woo00<007ooOol04Goo00<0
07ooOol08Woo00<007ooOol017oo00<007oo00001Woo00<007ooOol04Goo00<007ooOol08Woo00<0
07ooOol017oo00<007oo00001goo00<007ooOol0Cgoo000hOol6000kOol00`00Oomoo`05Ool00`00
Ool00006Ool00`00Oomoo`0AOol00`00Oomoo`0ROol00`00Oomoo`04Ool00`00Ool00006Ool00`00
Oomoo`0BOol00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Ool00006Ool00`00Oomoo`0BOol00`00
Oomoo`0QOol00`00Oomoo`04Ool00`00Ool00007Ool00`00Oomoo`1?Ool0039oo`H0049oo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo029oo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo01Aoo`03001oogoo025oo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo01Aoo`03001oogoo025oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo051oo`00;Goo
1@00BGoo00<007ooOol02Woo00<007ooOol05Goo00<007ooOol08Woo00<007ooOol02Goo00<007oo
Ool05Woo00<007ooOol08Goo00<007ooOol02Goo00<007ooOol05Woo00<007ooOol08Goo00<007oo
Ool02Woo00<007ooOol0DGoo000JOol00`00Oomoo`0:Ool6001dOol00`00Oomoo`16Ool00`00Oomo
o`16Ool00`00Oomoo`22Ool001Qoo`8000Moo`H007]oo`03001oogoo04Ioo`03001oogoo04Ioo`03
001oogoo085oo`005Woo0`000Woo1P00PGoo00<007ooOol0Agoo00<007ooOol0AWoo00<007ooOol0
P7oo000DOol70028Ool00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`1oOol000eoo`03001o
ogoo009oo`X008Qoo`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo07ioo`0037oo00<007oo
0000UWoo00<007ooOol0Agoo00<007ooOol0AWoo00<007ooOol0OGoo000<Ool00`00Ool0002GOol0
0`00Oomoo`16Ool00`00Oomoo`16Ool00`00Oomoo`1mOol0009oo`D000Eoo`03001oo`0009Moo`03
001oogoo04Moo`03001oogoo04Ioo`03001oogoo07aoo`000goo00D007ooOomoo`0000Aoo`03001o
o`0009Qoo`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo07]oo`000goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0V7oo00<007ooOol0Agoo00<007ooOol0AWoo00<007ooOol0NWoo
0004Ool01@00Oomoogoo0000X7oo00<007ooOol0Agoo00<007ooOol0AWoo00<007ooOol0NGoo0004
Ool20002Ool00`00Oomoo`07Ool:002>Ool00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`1h
Ool000Aoo`04001oo`00000;Ool7002AOol00`00Oomoo`16Ool00`00Oomoo`16Ool00`00Oomoo`1h
Ool000Aoo`03001oogoo00ioo`<0009oo`D008aoo`03001oogoo04Moo`03001oogoo04Ioo`03001o
ogoo07Moo`000goo0P004Woo0`001Goo1000RGoo00<007ooOol0Agoo00<007ooOol0AWoo00<007oo
Ool0MWoo000IOol20008Ool50025Ool00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`1eOol0
02Qoo`D0085oo`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo07Aoo`00;Goo1@00OGoo00<0
07ooOol0Agoo00<007ooOol0AWoo00<007ooOol0Lgoo000bOol5001hOol00`00Oomoo`17Ool00`00
Oomoo`16Ool00`00Oomoo`1cOol003Moo`D007Aoo`03001oogoo04Moo`03001oogoo04Ioo`03001o
ogoo079oo`00?7oo1000LGoo00<007ooOol0Agoo00<007ooOol0AWoo00<007ooOol0LGoo0010Ool5
001]Ool00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`1`Ool004Eoo`D006Uoo`03001oogoo
04Moo`03001oogoo04Ioo`03001oogoo06moo`00BWoo1@00IGoo00<007ooOol0Agoo00<007ooOol0
AWoo00<007ooOol0KWoo001?Ool5001POol00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`1^
Ool005Aoo`D005aoo`03001oogoo04Moo`03001oogoo04Ioo`03001oogoo06eoo`00FGoo10007Woo
00<007ooOol0>7oo00<007ooOol02Goo1@00>Goo00<007ooOol02Goo0`00>Woo00<007ooOol02Woo
0P00H7oo001MOol5000HOol00`00Ool00017Ool00`00Oomoo`15Ool00`00Oomoo`19Ool00`00Oomo
o`1MOol0069oo`D001=oo`03001oo`0004Moo`03001oogoo04Ioo`03001oogoo04Moo`03001oogoo
05ioo`00Igoo0`001goo10001Goo00<007oo0000?Goo10001Woo00<007ooOol0?Goo10001Goo00<0
07ooOol0?Goo10001goo00<007ooOol0>goo0P001Goo0P001Goo0P004Woo001`Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Ool0000lOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0l
Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0003eoo`03001oogoo009oo`03001oogoo009oo`03
001oo`0003eoo`8000Eoo`8000Eoo`80019oo`00L7oo00<007ooOol027oo00<007ooOol0>goo00<0
07ooOol01goo0P00?Woo00<007ooOol01goo00<007ooOol0?7oo00<007ooOol027oo00<007ooOol0
GWoo001`Ool00`00Oomoo`16Ool00`00Oomoo`17Ool00`00Oomoo`16Ool00`00Oomoo`1YOol0075o
o`05001oogooOol00014Ool01@00Oomoogoo0000AGoo00D007ooOomoo`0004Aoo`05001oogooOol0
001VOol0079oo`@004Eoo`@004Ioo`@004Eoo`@006Ioo`00ogoo^Goo001kOol00`00Oomoo`0>Ool0
0`00Oomoo`0fOol00`00Oomoo`0=Ool00`00Oomoo`0fOol00`00Oomoo`0=Ool00`00Oomoo`0fOol0
0`00Oomoo`0=Ool00`00Oomoo`1>Ool007Yoo`03001oogoo00Ioo`D000Eoo`03001oogoo03Aoo`03
001oogoo00Eoo`D000Eoo`03001oogoo03Aoo`03001oogoo00Eoo`D000Eoo`03001oogoo03Aoo`03
001oogoo00Eoo`D000Eoo`03001oogoo04eoo`00NGoo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol0<Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0<Woo00<007ooOol027oo00<0
07ooOol01Woo00<007ooOol0<Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0C7oo001i
Ool00`00Oomoo`03Ool30003Ool00`00Oomoo`06Ool00`00Oomoo`0bOol00`00Oomoo`02Ool30003
Ool00`00Oomoo`06Ool00`00Oomoo`0bOol00`00Oomoo`02Ool30003Ool00`00Oomoo`06Ool00`00
Oomoo`0bOol00`00Oomoo`02Ool30003Ool00`00Oomoo`06Ool00`00Oomoo`1<Ool007Uoo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo039oo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo039oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo039oo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo04aoo`00NGoo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol0<Woo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol0<Woo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol0<Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0C7oo001jOol00`00Oomo
o`07Ool20007Ool00`00Oomoo`0dOol00`00Oomoo`06Ool20007Ool00`00Oomoo`0dOol00`00Oomo
o`06Ool20007Ool00`00Oomoo`0dOol00`00Oomoo`06Ool20007Ool00`00Oomoo`1=Ool007]oo`03
001oogoo00ioo`03001oogoo03Ioo`03001oogoo00eoo`03001oogoo03Ioo`03001oogoo00eoo`03
001oogoo03Ioo`03001oogoo00eoo`03001oogoo04ioo`00ogoo^Goo003oOoniOol00?mookUoo`00
ogoo^Goo0000\
\>"],
  ImageRangeCache->{{{144.563, 583.563}, {246.938, 67.9375}} -> {-158.068, 
  58.0292, 1.09341, 1.36675}}],

Cell["\<\

Table 1\
\>", "Text",
  TextAlignment->Center,
  FontWeight->"Plain"],

Cell[TextData[{
  "From Theorems 12.7 b, 12.7 a and 12.6 c of [3] one obtains the ",
  StyleBox["continued fraction criterion",
    FontSlant->"Italic"],
  ":"
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell["Theorem 6", "Subsubsection"],

Cell["The polynomial ", "Text",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`p(z) := 
      a\_0 + \(a\_1\) z + \(a\_2\) z\^2 + \[CenterEllipsis] + 
        \(a\_N\) z\^N\)]]], "DisplayFormula",
  FontWeight->"Plain"],

Cell[TextData[{
  StyleBox["of degree ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " ",
  StyleBox[
  "with real coefficients is stable if and only if the rational function",
    FontSlant->"Italic"]
}], "Text",
  FontSlant->"Italic"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm
    \`\(a\_1 + \(a\_3\) z + \(a\_5\) z\^2 + \[CenterEllipsis]\)\/\(a\_0 + 
          \(a\_2\) z + \(a\_4\) z\^2 + \[CenterEllipsis]\) = 
      \(\[Sum]\+\(k = 0\)\%\([\((N - 1)\)/2]\)\(a\_\(2  k + 1\)\) 
            z\^k\)\/\(\[Sum]\+\(k = 0\)\%\([N/2]\)\(a\_\(2  k\)\) 
            z\^k\)\)]]], "NumberedEquation",
  FontWeight->"Plain"],

Cell[TextData[{
  "(",
  StyleBox["the Hurwitz alternant of the polynomial ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ") ",
  StyleBox["can be represented by such an ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-",
  StyleBox[
  "terminating continued fraction of the form (8), in which every number ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`b\_k\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((k = 1, 2, \[CenterEllipsis], n)\)\)]],
  " ",
  StyleBox["is positive. ",
    FontSlant->"Italic"]
}], "Text",
  FontSlant->"Italic"],

Cell["A possible code of this criterion follows.", "Text",
  FontWeight->"Plain"],

Cell[BoxData[
    \(CFCriterion[polyvalue_, variable_] := \n
      Module[\n{cf = CoefficientList[polyvalue, variable], \n\ \ \ \ \ \ \ 
          deg, \ cfde, cfnu, b, sQ, temp = {}, m = 1}, \n
        deg = Length[cf] - 1; \nsQ = \(! FreeQ[NumberQ/@cf, False]\); \n
        cfnu = Table[cf[\([k]\)], {k, 2, deg + 1, 2}]; \n
        cfde = Table[cf[\([k]\)], {k, 1, deg + 1, 2}]; \n
        While[\((
            \((First[cfnu] > 0\  \[And] \ m < deg + 1)\) \[Or] \n\ \ \ \ \ 
              \((sQ \[And] m < deg + 1)\))\), \n
          b[m] = First[cfnu]\/First[cfde]; \n
          If[Length[cfnu] < Length[cfde], \n\t\t\tcfnu = Join[cfnu, {0}]]; \n
          temp = cfnu; \ncfnu = Drop[b[m]*cfde - cfnu, 1]; \ncfde = temp; \n
          m = m + 1]; \n
        If[m < deg, "\<Unstable\>", 
          If[\(! sQ\), "\<Stable\>", \n\ \ \ \ \ 
            Together[Simplify[Table[b[k], {k, 1, m - 1}]]]]]]\)], "Input",
  CellLabel->"In[46]:="],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[
      \(\(CFCriterion[#[z], z]&\)\ /@
        \ {p\_1, p\_2, p\_4, p\_5, p\_6, p\_7, p\_8, p\_9}\),
      FontColor->GrayLevel[0]]], "Input",
  CellLabel->"In[47]:=",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \({"Unstable", "Stable", "Stable", "Stable", "Unstable", "Unstable", 
      "Stable", "Unstable"}\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(CFCriterion[p\_10[z], z]\),
      FontColor->GrayLevel[0]]], "Input",
  CellLabel->"In[48]:=",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \({b, \(\(-1\) + a\ b\)\/b, 1\/b}\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(CFCriterion[p\_11[z], z]\),
      FontColor->GrayLevel[0]]], "Input",
  CellLabel->"In[49]:=",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \({c, \(\(-a\) + b\ c\)\/c, 
      \(\(-a\^2\) + a\ b\ c - c\^2\)\/\(c\ \((\(-a\) + b\ c)\)\), 
      \(-\(c\/\(a - b\ c\)\)\)}\)], "Output",
  CellLabel->"Out[49]="]
}, Open  ]],

Cell[TextData[StyleBox[
"As it can be seen, in the case of paramteric coefficients those expressions \
are provided the positivity of which has to be checked."]], "Text",
  FontWeight->"Plain"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8 A PACKAGE FOR SUMMARY", "Section"],

Cell[TextData[{
  "The code fragments above are summarized into a single function called ",
  StyleBox["StablePolynomialQ ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "with the default value ",
  StyleBox["NegativeRealParts",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  of its option ",
  StyleBox["Method.",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " Our aim was not to produce a final version of a package, as we think that \
further experiments (e.g. with automatic investigation of positivity with the \
new possibilities of version 3.0) are needed to produce a 'product' which can \
be used by everybody with confidence. We formulated the function in such a \
way that it gives an answer which is either ",
  StyleBox["True ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "or",
  StyleBox[" False, ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "or it gives an expression to be investigated further. This expression is \
given in different forms when different methods are used. The function itself \
is to be contained in a separate file attached to the electronic attachment \
of the journal. Below we show the results obtained when one investigates the \
same polynomials as above. "
}], "Text",
  FontWeight->"Plain"],

Cell[CellGroupData[{

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p\_3\)]],
  " with different parameters"
}], "Subsection"],

Cell[BoxData[
    \(\(StablePolynomialQ[p\_3[z, a], z]; \)\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\(StablePolynomialQ[p\_3[z, a], z, Method \[Rule] NegativeRealParts]; 
    \)\)], "Input",
  CellLabel->"In[28]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(StablePolynomialQ[p\_3[z, a], z, Method \[Rule] Stodola]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(Sign[a] == 1\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StablePolynomialQ[#, z]&\)\ /@\ polylist1\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \({False, False, True, True, True, False}\)], "Output",
  CellLabel->"Out[32]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Results on polylist2", "Subsection"],

Cell[BoxData[
    \(\(polylist2
       = {p\_1, p\_2, p\_4, p\_5, p\_6, p\_7, p\_8, p\_9, p\_10, p\_11}; 
    \)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drop[\(StablePolynomialQ[#[z], z]&\)\ /@\ polylist2, \(-2\)]\)], "Input",\

  CellLabel->"In[76]:="],

Cell[BoxData[
    \({False, True, True, True, False, False, True, False}\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Drop[
      \(StablePolynomialQ[\n#[z], z, Method \[Rule] NegativeRealParts]&\)\ /@
        \ polylist2, \(-2\)]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \({False, True, True, True, False, False, True, False}\)], "Output",
  CellLabel->"Out[39]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StablePolynomialQ[#[z], z, Method \[Rule] Stodola]&\)\ /@\ polylist2
      \)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \({True, True, True, True, False, True, True, True, 
      Sign[b] == Sign[a] == 1, Sign[c] == Sign[b] == Sign[a] == 1}\)], 
  "Output",
  CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StablePolynomialQ[#[z], z, Method \[Rule] RouthHurwitz]&\)\ /@\ 
      polylist2\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \({"False", "True", "True", "True", "False", "False", "True", "False", 
      Positive[a] && Positive[\(-1\) + a\ b] && Positive[\(-1\) + a\ b], 
      Positive[a] && Positive[a\ b - c] && 
        Positive[\(-a\^2\) + a\ b\ c - c\^2] && 
        Positive[\(-a\^2\) + a\ b\ c - c\^2]}\)], "Output",
  CellLabel->"Out[41]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StablePolynomialQ[#[z], z, Method \[Rule] LienardChippart]&\)\ /@\ 
      polylist2\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \({"False", "True", "True", "True", "False", "False", "True", "False", 
      Sign[b] == Sign[a] == 1 && Positive[\(-1\) + a\ b], 
      Sign[c] == Sign[b] == Sign[a] == 1 && 
        Positive[\(-a\^2\) + a\ b\ c - c\^2] && Positive[a]}\)], "Output",
  CellLabel->"Out[74]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StablePolynomialQ[#[z], z, Method \[Rule] Euclidean]&\)\ /@\ polylist2
      \)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \({"False", "True", "True", "True", "False", "False", "True", "False", 
      1\/a > 0 && a\^2\/\(\(-1\) + a\ b\) > 0 && \(\(-1\) + a\ b\)\/a > 0, 
      1\/a > 0 && a\^2\/\(a\ b - c\) > 0 && 
        \(-\(\((a\ b - c)\)\^2\/\(a\ \((a\^2 - a\ b\ c + c\^2)\)\)\)\) > 0 && 
        \(a\^2 - a\ b\ c + c\^2\)\/\(\(-a\)\ b + c\) > 0}\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(StablePolynomialQ[#[z], z, Method \[Rule] ContinuedFraction]&\)\ /@\ 
      polylist2\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \({"False", "True", "True", "True", "False", "False", "True", 
      "False", {b, \(\(-1\) + a\ b\)\/b, 1\/b}, {c, \(\(-a\) + b\ c\)\/c, 
        \(\(-a\^2\) + a\ b\ c - c\^2\)\/\(c\ \((\(-a\) + b\ c)\)\), 
        \(-\(c\/\(a - b\ c\)\)\)}}\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ACKNOWLEDGEMENT", "Section"],

Cell[TextData[StyleBox[
"The present work has partly been supported by the grants No. MKM 419/1995 \
and MKM 184/1996 of the Hungarian Ministry for Education and Culture. The \
authors benefited from the advice given by the referee."]], "Text",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["REFERENCES", "Section",
  FontWeight->"Plain"],

Cell[TextData[{
  "[1] Corless, R. M.: Simple engineering mathematics with Maple, ",
  StyleBox["MapleTech",
    FontSlant->"Italic"],
  " ",
  StyleBox["3",
    FontWeight->"Bold"],
  " (1) (1966) 2\[Dash]7."
}], "Reference",
  FontWeight->"Plain"],

Cell[TextData[{
  "[2] Henrici, P.: ",
  StyleBox["Applied and Computational Complex Analysis. ",
    FontSlant->"Italic"],
  "Vol. I. John  Wiley & Sons, New York, London, Sydney, Toronto (1974)."
}], "Reference",
  FontWeight->"Plain"],

Cell[TextData[{
  "[3] Henrici, P.: ",
  StyleBox["Applied and Computational Complex Analysis. ",
    FontSlant->"Italic"],
  "Vol. II. John  Wiley & Sons, New York, London, Sydney, Toronto (1977)."
}], "Reference",
  FontWeight->"Plain"],

Cell[TextData[{
  "[4] Postnikov, M. M.: ",
  StyleBox["Stable polynomials. ",
    FontSlant->"Italic"],
  "Nauka, Moscow (1981) (in Russian). "
}], "Reference",
  FontWeight->"Plain"],

Cell[TextData[{
  "[5] Szili, L., T\[OAcute]th, J.: ",
  StyleBox["Mathematics and Mathematica.",
    FontSlant->"Italic"],
  " ELTE E\[ODoubleDot]tv\[ODoubleDot]s Kiad\[OAcute], Budapest (1996) (in \
Hungarian)."
}], "Reference",
  FontWeight->"Plain"],

Cell[TextData[{
  "[6] Wolfram, S.: ",
  StyleBox["The Mathematica Book. ",
    FontSlant->"Italic"],
  "(Third edition) Wolfram Media\[Dash]Cambridge University Press (1996)."
}], "Reference",
  FontWeight->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ABOUT THE AUTHORS", "Section"],

Cell[TextData[{
  "J\[AAcute]nos T\[OAcute]th received his diploma in mathematics at the Lor\
\[AAcute]nd E\[ODoubleDot]tv\[ODoubleDot]s University of Budapest in 1971. \
Currently he is head of the Department of Computer Science, Agricultural \
University, G\[ODoubleDot]d\[ODoubleDot]ll\[OTilde], and participates in \
teaching at Lor\[AAcute]nd E\[ODoubleDot]tv\[ODoubleDot]s University as well. \
His primary research interest is in deterministic and stochastic modelling of \
chemical reactions with emphasis on the reduction of the number of variables. \
He is the author of several books, including ",
  StyleBox["Mathematical Models of Chemical Reactions ",
    FontSlant->"Italic"],
  "with P. \[CapitalEAcute]rdi copublished by Manchester University Press and \
Princeton University Press."
}], "Text",
  FontWeight->"Plain"],

Cell[TextData[
"J\[AAcute]nos T\[OAcute]th\nDepartment of Computer Science\nAgricultural \
University\nP\[AAcute]ter K. u. 1.\nH\[Dash]2103 \
G\[ODoubleDot]d\[ODoubleDot]ll\[OTilde], HUNGARY\ntothj@mszi.gau.hu, \
jtoth@helka.iif.hu"], "Text",
  FontWeight->"Plain"],

Cell["\<\
L\[AAcute]szl\[OAcute] Szili received his diploma as a teacher of mathematics \
and physics at the Lor\[AAcute]nd E\[ODoubleDot]tv\[ODoubleDot]s University \
of Budapest in 1978. Currently he is assistant professor at the Department of \
Numerical Analysis, Lor\[AAcute]nd E\[ODoubleDot]tv\[ODoubleDot]s University, \
Budapest.  His primary research interest is in approximation theory on which \
topics he has published a dozen of papers. He is also interested in the \
theory, in the numerical methods and in the applications of differential \
equations.\
\>", "Text",
  FontWeight->"Plain"],

Cell[TextData[
"L\[AAcute]szl\[OAcute] Szili\nDepartment of Numerical Analysis\n\
Lor\[AAcute]nd E\[ODoubleDot]tv\[ODoubleDot]s University\nM\[UAcute]zeum krt. \
6\[Dash]8.\nH\[Dash]1088 Budapest, HUNGARY\nszili@ludens.elte.hu"], "Text",
  FontWeight->"Plain"],

Cell["\<\
Andr\[AAcute]s Zach\[AAcute]r received his diploma in mechanical engineering \
at the Faculty for Agricultural Mechanical Engineering, Agricultural \
University, G\[ODoubleDot]d\[ODoubleDot]ll\[OTilde]. Currently he is a \
teaching assistant at the  Department of Computer Science, Agricultural \
University, G\[ODoubleDot]d\[ODoubleDot]ll\[OTilde], and a PhD student in \
mathematical modelling at the Department of Physics and Process Control of \
the same university. His primary research interest is in modelling technical \
phenomena using ordinary and partial differential equations.\
\>", "Text",
  FontWeight->"Plain"],

Cell[TextData[
"Andr\[AAcute]s Zach\[AAcute]r\nDepartment of Computer Science\nAgricultural \
University\nP\[AAcute]ter K. u. 1.\nH\[Dash]2103 \
G\[ODoubleDot]d\[ODoubleDot]ll\[OTilde], HUNGARY\nazachar@mszi.gau.hu"], 
  "Text",
  ImageSize->{147, 147},
  FontWeight->"Plain"],

Cell["\<\

\
\>", "Text",
  FormatType->TextForm]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1024}, {0, 712}},
ScreenStyleEnvironment->"Working",
ShowPageBreaks->True,
WindowSize->{1008, 705},
WindowMargins->{{-4, Automatic}, {-4, Automatic}},
PrintingCopies->1,
PrintingPageRange->{14, 14},
PageHeaders->{{Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
        TextData[ {"Stability of Polynomials"}], "Header"]}, {Cell[ 
        TextData[ {"J. T\[OAcute]th - L. Szili - A. Zach\[AAcute]r"}], 
        "Header"], Inherited, Cell[ 
        TextData[ {
          CounterBox[ "Page"]}], "PageNumber"]}},
PrintingOptions->{"FacingPages"->True},
PrivateFontOptions->{"FontType"->"Outline"},
StyleDefinitions -> "ArticleModern.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 41, 0, 32, "Title"],
Cell[1775, 53, 399, 9, 93, "Abstract"],

Cell[CellGroupData[{
Cell[2199, 66, 156, 3, 48, "Author"],

Cell[CellGroupData[{
Cell[2380, 73, 33, 0, 57, "Section"],
Cell[2416, 75, 149, 3, 19, "Text"],
Cell[2568, 80, 312, 9, 28, "NumberedEquation"],
Cell[2883, 91, 749, 23, 49, "Text"],
Cell[3635, 116, 309, 6, 49, "Text"],
Cell[3947, 124, 452, 7, 64, "Text"],
Cell[4402, 133, 372, 6, 49, "Text"],
Cell[4777, 141, 426, 10, 49, "Text"],
Cell[5206, 153, 318, 10, 34, "Text"],
Cell[5527, 165, 360, 7, 49, "Text"],
Cell[5890, 174, 361, 11, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6288, 190, 40, 0, 57, "Section"],
Cell[6331, 192, 404, 12, 34, "Text"],
Cell[6738, 206, 115, 2, 19, "Text"],
Cell[6856, 210, 163, 3, 58, "Input"],
Cell[7022, 215, 439, 14, 34, "Text"],
Cell[7464, 231, 101, 1, 19, "Text"],
Cell[7568, 234, 194, 4, 74, "Input"],
Cell[7765, 240, 193, 7, 20, "Text"],

Cell[CellGroupData[{
Cell[7983, 251, 76, 2, 42, "Input"],
Cell[8062, 255, 62, 2, 41, "Output"]
}, Open  ]],
Cell[8139, 260, 132, 4, 19, "Text"],

Cell[CellGroupData[{
Cell[8296, 268, 76, 2, 42, "Input"],
Cell[8375, 272, 62, 2, 41, "Output"]
}, Open  ]],
Cell[8452, 277, 1293, 46, 51, "Text"],

Cell[CellGroupData[{
Cell[9770, 327, 185, 5, 86, "Input"],
Cell[9958, 334, 1373, 49, 117, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11368, 388, 100, 2, 42, "Input"],
Cell[11471, 392, 405, 14, 97, "Output"]
}, Open  ]],
Cell[11891, 409, 135, 4, 19, "Text"],

Cell[CellGroupData[{
Cell[12051, 417, 79, 2, 42, "Input"],
Cell[12133, 421, 70, 2, 41, "Output"]
}, Open  ]],
Cell[12218, 426, 336, 11, 34, "Text"],

Cell[CellGroupData[{
Cell[12579, 441, 80, 2, 42, "Input"],
Cell[12662, 445, 126, 3, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[12837, 454, 97, 2, 74, "Section"],
Cell[12937, 458, 313, 10, 34, "Text"],

Cell[CellGroupData[{
Cell[13275, 472, 188, 4, 58, "Input"],
Cell[13466, 478, 79982, 1259, 193, 4788, 326, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93485, 1742, 166, 3, 58, "Input"],
Cell[93654, 1747, 77414, 1163, 193, 3285, 243, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[171083, 2913, 383, 10, 34, "Text"],

Cell[CellGroupData[{
Cell[171491, 2927, 156, 4, 42, "Input"],
Cell[171650, 2933, 402, 7, 71, "Output"]
}, Open  ]],
Cell[172067, 2943, 352, 10, 36, "Text"],
Cell[172422, 2955, 676, 18, 66, "Text"],
Cell[173101, 2975, 190, 6, 20, "Text"],
Cell[173294, 2983, 190, 4, 90, "Input"],
Cell[173487, 2989, 84, 1, 19, "Text"],

Cell[CellGroupData[{
Cell[173596, 2994, 392, 7, 167, "Input"],
Cell[173991, 3003, 105, 2, 41, "Output"]
}, Open  ]],
Cell[174111, 3008, 424, 11, 50, "Text"],
Cell[174538, 3021, 141, 4, 59, "Input"],
Cell[174682, 3027, 87, 1, 19, "Text"],
Cell[174772, 3030, 89, 2, 42, "Input"],
Cell[174864, 3034, 540, 12, 64, "Text"],
Cell[175407, 3048, 147, 4, 59, "Input"],
Cell[175557, 3054, 58, 1, 19, "Text"],
Cell[175618, 3057, 163, 4, 42, "Input"],
Cell[175784, 3063, 194, 6, 19, "Text"],
Cell[175981, 3071, 237, 7, 20, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176255, 3083, 68, 0, 57, "Section"],
Cell[176326, 3085, 191, 4, 34, "Text"],
Cell[176520, 3091, 417, 9, 49, "Text"],
Cell[176940, 3102, 324, 10, 25, "DisplayFormula"],
Cell[177267, 3114, 547, 15, 49, "Text"],
Cell[177817, 3131, 199, 6, 19, "Text"],

Cell[CellGroupData[{
Cell[178041, 3141, 34, 0, 39, "Subsubsection"],
Cell[178078, 3143, 1018, 36, 49, "Text"],
Cell[179099, 3181, 178, 6, 19, "Text"],

Cell[CellGroupData[{
Cell[179302, 3191, 424, 8, 123, "Input"],
Cell[179729, 3201, 79537, 1193, 193, 4713, 264, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[259281, 4397, 400, 11, 49, "Text"],

Cell[CellGroupData[{
Cell[259706, 4412, 475, 9, 139, "Input"],
Cell[260184, 4423, 80331, 1299, 193, 7394, 394, "GraphicsData", 
"PostScript", "Graphics"]
}, Open  ]],
Cell[340530, 5725, 182, 3, 34, "Text"],
Cell[340715, 5730, 386, 10, 34, "Text"],
Cell[341104, 5742, 217, 7, 19, "Text"],
Cell[341324, 5751, 534, 15, 27, "NumberedEquation"],
Cell[341861, 5768, 275, 9, 19, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[342173, 5782, 34, 0, 39, "Subsubsection"],
Cell[342210, 5784, 851, 32, 49, "Text"],
Cell[343064, 5818, 154, 4, 24, "DisplayFormula"],
Cell[343221, 5824, 271, 4, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[343541, 5834, 74, 0, 57, "Section"],
Cell[343618, 5836, 669, 18, 64, "Text"],
Cell[344290, 5856, 193, 6, 19, "Text"],
Cell[344486, 5864, 1003, 20, 96, "NumberedEquation"],
Cell[345492, 5886, 190, 3, 34, "Text"],
Cell[345685, 5891, 267, 12, 25, "DisplayFormula"],
Cell[345955, 5905, 50, 1, 19, "Text"],
Cell[346008, 5908, 336, 9, 38, "DisplayFormula"],
Cell[346347, 5919, 169, 3, 19, "Text"],

Cell[CellGroupData[{
Cell[346541, 5926, 34, 0, 39, "Subsubsection"],
Cell[346578, 5928, 456, 19, 34, "Text"],
Cell[347037, 5949, 714, 14, 78, "NumberedEquation"],
Cell[347754, 5965, 246, 8, 19, "Text"],
Cell[348003, 5975, 136, 3, 19, "Text"],
Cell[348142, 5980, 422, 7, 189, "Input"],
Cell[348567, 5989, 109, 2, 19, "Text"],
Cell[348679, 5993, 157, 3, 58, "Input"],
Cell[348839, 5998, 73, 1, 19, "Text"],

Cell[CellGroupData[{
Cell[348937, 6003, 84, 2, 42, "Input"],
Cell[349024, 6007, 318, 11, 61, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[349379, 6023, 84, 2, 42, "Input"],
Cell[349466, 6027, 365, 12, 73, "Output"]
}, Open  ]],
Cell[349846, 6042, 114, 2, 19, "Text"],
Cell[349963, 6046, 171, 3, 58, "Input"],
Cell[350137, 6051, 112, 2, 19, "Text"],

Cell[CellGroupData[{
Cell[350274, 6057, 185, 4, 42, "Input"],
Cell[350462, 6063, 92, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[350591, 6070, 315, 10, 42, "Input"],
Cell[350909, 6082, 135, 3, 41, "Output"]
}, Open  ]],
Cell[351059, 6088, 157, 3, 19, "Text"],
Cell[351219, 6093, 302, 5, 123, "Input"],
Cell[351524, 6100, 148, 3, 19, "Text"],

Cell[CellGroupData[{
Cell[351697, 6107, 145, 3, 42, "Input"],
Cell[351845, 6112, 154, 3, 56, "Output"]
}, Open  ]],
Cell[352014, 6118, 187, 3, 34, "Text"],

Cell[CellGroupData[{
Cell[352226, 6125, 83, 2, 42, "Input"],
Cell[352312, 6129, 127, 3, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[352476, 6137, 83, 2, 42, "Input"],
Cell[352562, 6141, 186, 4, 56, "Output"]
}, Open  ]],
Cell[352763, 6148, 305, 5, 49, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[353105, 6158, 34, 0, 39, "Subsubsection"],
Cell[353142, 6160, 412, 16, 34, "Text"],
Cell[353557, 6178, 209, 4, 24, "DisplayFormula"],
Cell[353769, 6184, 56, 1, 19, "Text"],
Cell[353828, 6187, 387, 13, 36, "Text"],
Cell[354218, 6202, 2839, 74, 139, "Input"],
Cell[357060, 6278, 84, 1, 19, "Text"],

Cell[CellGroupData[{
Cell[357169, 6283, 220, 5, 58, "Input"],
Cell[357392, 6290, 154, 3, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[357583, 6298, 86, 2, 42, "Input"],
Cell[357672, 6302, 109, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[357818, 6309, 86, 2, 42, "Input"],
Cell[357907, 6313, 155, 3, 56, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[358123, 6323, 40, 0, 57, "Section"],
Cell[358166, 6325, 225, 4, 34, "Text"],
Cell[358394, 6331, 170, 4, 34, "Text"],
Cell[358567, 6337, 1733, 48, 24, "DisplayFormula"],
Cell[360303, 6387, 642, 19, 49, "Text"],
Cell[360948, 6408, 707, 16, 120, "NumberedEquation"],
Cell[361658, 6426, 972, 29, 34, "Text"],
Cell[362633, 6457, 95, 1, 19, "Text"],

Cell[CellGroupData[{
Cell[362753, 6462, 34, 0, 39, "Subsubsection"],
Cell[362790, 6464, 516, 22, 34, "Text"],
Cell[363309, 6488, 249, 6, 27, "NumberedEquation"],
Cell[363561, 6496, 67, 2, 19, "Text"],
Cell[363631, 6500, 318, 8, 27, "NumberedEquation"],
Cell[363952, 6510, 182, 6, 19, "Text"],
Cell[364137, 6518, 1233, 25, 277, "Input"],

Cell[CellGroupData[{
Cell[365395, 6547, 142, 3, 42, "Input"],
Cell[365540, 6552, 154, 3, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[365731, 6560, 80, 2, 42, "Input"],
Cell[365814, 6564, 129, 3, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[365980, 6572, 80, 2, 42, "Input"],
Cell[366063, 6576, 229, 4, 56, "Output"]
}, Open  ]],
Cell[366307, 6583, 461, 15, 36, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[366817, 6604, 49, 0, 57, "Section"],
Cell[366869, 6606, 163, 4, 19, "Text"],
Cell[367035, 6612, 287, 9, 19, "Text"],
Cell[367325, 6623, 341, 9, 57, "NumberedEquation"],
Cell[367669, 6634, 469, 12, 34, "Text"],
Cell[368141, 6648, 97, 1, 19, "Text"],
Cell[368241, 6651, 250, 6, 32, "NumberedEquation"],
Cell[368494, 6659, 338, 11, 19, "Text"],
Cell[368835, 6672, 353, 14, 28, "NumberedEquation"],
Cell[369191, 6688, 254, 6, 19, "Text"],
Cell[369448, 6696, 862, 19, 128, "NumberedEquation"],
Cell[370313, 6717, 558, 16, 49, "Text"],
Cell[370874, 6735, 81138, 2479, 196, 61393, 2231, "GraphicsData", 
"PostScript", "Graphics"],
Cell[452015, 9216, 80, 5, 34, "Text"],
Cell[452098, 9223, 194, 6, 19, "Text"],

Cell[CellGroupData[{
Cell[452317, 9233, 34, 0, 39, "Subsubsection"],
Cell[452354, 9235, 77, 2, 19, "Text"],
Cell[452434, 9239, 196, 5, 24, "DisplayFormula"],
Cell[452633, 9246, 268, 10, 19, "Text"],
Cell[452904, 9258, 388, 7, 37, "NumberedEquation"],
Cell[453295, 9267, 635, 24, 34, "Text"],
Cell[453933, 9293, 81, 1, 19, "Text"],
Cell[454017, 9296, 939, 17, 354, "Input"],

Cell[CellGroupData[{
Cell[454981, 9317, 226, 6, 42, "Input"],
Cell[455210, 9325, 154, 3, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455401, 9333, 155, 4, 42, "Input"],
Cell[455559, 9339, 90, 2, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[455686, 9346, 155, 4, 42, "Input"],
Cell[455844, 9352, 184, 4, 56, "Output"]
}, Open  ]],
Cell[456043, 9359, 193, 3, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[456285, 9368, 42, 0, 57, "Section"],
Cell[456330, 9370, 1283, 31, 127, "Text"],

Cell[CellGroupData[{
Cell[457638, 9405, 115, 4, 52, "Subsection"],
Cell[457756, 9411, 96, 2, 42, "Input"],
Cell[457855, 9415, 135, 3, 58, "Input"],

Cell[CellGroupData[{
Cell[458015, 9422, 114, 2, 42, "Input"],
Cell[458132, 9426, 71, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[458240, 9433, 101, 2, 42, "Input"],
Cell[458344, 9437, 98, 2, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[458491, 9445, 42, 0, 52, "Subsection"],
Cell[458536, 9447, 125, 3, 42, "Input"],

Cell[CellGroupData[{
Cell[458686, 9454, 120, 3, 42, "Input"],
Cell[458809, 9459, 111, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[458957, 9466, 170, 4, 58, "Input"],
Cell[459130, 9472, 111, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[459278, 9479, 135, 3, 58, "Input"],
Cell[459416, 9484, 179, 4, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[459632, 9493, 140, 3, 58, "Input"],
Cell[459775, 9498, 341, 6, 86, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[460153, 9509, 143, 3, 74, "Input"],
Cell[460299, 9514, 293, 5, 86, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[460629, 9524, 137, 3, 58, "Input"],
Cell[460769, 9529, 386, 6, 106, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[461192, 9540, 145, 3, 74, "Input"],
Cell[461340, 9545, 298, 5, 74, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[461699, 9557, 34, 0, 57, "Section"],
Cell[461736, 9559, 267, 4, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[462040, 9568, 52, 1, 57, "Section"],
Cell[462095, 9571, 249, 9, 16, "Reference"],
Cell[462347, 9582, 237, 6, 24, "Reference"],
Cell[462587, 9590, 238, 6, 24, "Reference"],
Cell[462828, 9598, 184, 6, 16, "Reference"],
Cell[463015, 9606, 253, 7, 16, "Reference"],
Cell[463271, 9615, 216, 6, 16, "Reference"]
}, Open  ]],

Cell[CellGroupData[{
Cell[463524, 9626, 36, 0, 57, "Section"],
Cell[463563, 9628, 835, 14, 94, "Text"],
Cell[464401, 9644, 265, 5, 94, "Text"],
Cell[464669, 9651, 603, 10, 79, "Text"],
Cell[465275, 9663, 260, 4, 94, "Text"],
Cell[465538, 9669, 636, 10, 79, "Text"],
Cell[466177, 9681, 276, 6, 94, "Text"],
Cell[466456, 9689, 49, 4, 34, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

